@@ -56,14 +56,6 @@ class StartQT4(QtGui.QMainWindow):
             self.ui.actionClose_Tab : self.closeTab,
             self.ui.actionQuit : self.close,
 
-            self.ui.actionView_PDF : lambda: api.previewPDF(self.currentBackendCollection(), pdfviewer = config.pdfviewer),
-            self.ui.actionTo_Lilybin_com : lambda: api.exportLilyBin(workspace = self.currentBackendCollection()),
-            self.ui.actionLilypond : self.exportLilypond,
-            self.ui.actionArdour_3 : self.exportArdour,
-            self.ui.actionPDF : self.exportPDF,
-            self.ui.actionMidi : self.exportMidi,
-            self.ui.actionMidi_Jack_Settings : self.exportMidiJack,
-
             self.ui.actionNew_Part : lambda: self.currentTabWidget().createEmptyPart() ,
             self.ui.actionMove_Part_up : lambda: self.currentTabWidget().up() ,
             self.ui.actionMove_Part_down : lambda: self.currentTabWidget().down() ,
@@ -159,6 +151,7 @@ class StartQT4(QtGui.QMainWindow):
 
             tab.ui.templat.addItems(list(api.getTemplateList(tab.backendCollection, extension = "ly"))) #not a typo, it really is "templat"
             tab.ui.templat.setCurrentIndex(tab.ui.templat.findText(ly))
+
             tab.ui.ardourTemplate.addItems(list(api.getTemplateList(tab.backendCollection, extension = "ardour")))
             tab.ui.ardourTemplate.setCurrentIndex(tab.ui.ardourTemplate.findText(ard))
 
@@ -170,36 +163,6 @@ class StartQT4(QtGui.QMainWindow):
 
     #Simple/Quick Exports. No parts.
 
-    def exportMidi(self):
-        fileName = QtGui.QFileDialog.getSaveFileName(self, "Export each Laborejo Score (combined of parts) as midi file. Give a base filename.", self.last_export_dir, "*.mid *.midi *.MID *.MIDI;;All Files (*.*)")
-        if fileName:
-            api.exportMidi(fileName, self.currentBackendCollection(), parts = None)
-            self.last_export_dir = os.path.dirname(fileName)
-
-    def exportMidiJack(self):
-        fileName = QtGui.QFileDialog.getSaveFileName(self, "Export each Laborejo Score (combined of parts) as midi file. Give a base filename.", self.last_export_dir, "*.mid *.midi *.MID *.MIDI;;All Files (*.*)")
-        if fileName:
-            api.exportMidi(fileName, self.currentBackendCollection(), jackMode = True, parts = None)
-            self.last_export_dir = os.path.dirname(fileName)
-
-    def exportArdour(self):
-        dirName = QtGui.QFileDialog.getExistingDirectory(self, caption = "Export Ardour 3 Session. Choose a directory where ANOTHER directory will be created.", directory = self.last_export_dir)
-        if dirName:
-            api.exportArdourThree(directory = dirName, workspace = self.currentBackendCollection(), parts = None)
-            self.last_export_dir = dirName
-
-    def exportLilypond(self):
-        fileName = QtGui.QFileDialog.getSaveFileName(self, "Export complete Laborejo Session to a single Lilypond file. Give full name including file extension.", self.last_export_dir, "*.ly;;All Files (*.*)")
-        if fileName:
-            api.exportLilypond(fileName, workspace = self.currentBackendCollection(), parts = None)
-            self.last_export_dir = os.path.dirname(fileName)
-
-    def exportPDF(self):
-        fileName = QtGui.QFileDialog.getSaveFileName(self, "Export Laborejo Collection to a single PDF file (Lilypond)", self.last_export_dir, "*.pdf;;All Files (*.*)")
-        if fileName:
-            api.exportPDF(fileName, workspace = self.currentBackendCollection(), lilypondbinary = config.lilypondbinary, parts = None)
-            self.last_export_dir = os.path.dirname(fileName)
-
     def switchActionsOn(self):
         """Switch menu actions related to an open file on"""
         for a in self.allActions:
@@ -409,6 +372,7 @@ class EditTab(QtGui.QScrollArea):
         self.ui.printallheader.setCurrentIndex(self.backendCollection.printallheader) #printallheader combobox indices: 0-Template default 1-Yes 2-No
         self.ui.smfTransposition.setValue(self.backendCollection.smfTransposition)
         self.ui.jackTransposition.setValue(self.backendCollection.jackTransposition)
+        self.ui.splitByToHeader.setChecked(self.backendCollection.splitByToHeader)
 
         self.ui.transposeFrom.addItems(api.lilypond.sortedNoteNameList)
         self.ui.transposeTo.addItems(api.lilypond.sortedNoteNameList)
@@ -461,6 +425,9 @@ class EditTab(QtGui.QScrollArea):
         self.ui.jackTransposition.valueChanged.connect(lambda: setattr(self.backendCollection, "jackTransposition", self.ui.jackTransposition.value()))
         self.ui.jackTransposition.valueChanged.connect(lambda: main.clearSaveStatus.__setitem__(self.backendCollection, False))
 
+        self.ui.splitByToHeader.stateChanged.connect(lambda: setattr(self.backendCollection, "splitByToHeader", self.ui.splitByToHeader.checkState()))
+        self.ui.splitByToHeader.stateChanged.connect(lambda: main.clearSaveStatus.__setitem__(self.backendCollection, False))
+
         #It is possible that you got an lbjs file without the template.
         warning = []
         self.lilypondTemplatesList = list(api.getTemplateList(workspace = self.backendCollection , extension = "ly"))
@@ -483,9 +450,26 @@ class EditTab(QtGui.QScrollArea):
             self.ui.warningLabel.setText("<span style='background-color:yellow'>" + warning + "</span>")
             self.ui.warningLabel.show()
 
-        #Connect the export button
+        #Connect the export button and preview button
         self.ui.exportnow.clicked.connect(self.export)
+        self.ui.previewButton.clicked.connect(self.preview)
 
+        #The Preview button is only available when choosing PDF. Also hovering preview disables the path field.
+        self.ui.pdf.toggled.connect(lambda: self.ui.previewButton.setEnabled(self.ui.pdf.isChecked()))
+        self.ui.previewButton.setEnabled(self.ui.pdf.isChecked())
+
+        def leavePreview(event):
+            if self.ui.previewButton.isEnabled(): self.ui.path.setEnabled(True)
+            event.accept()
+
+        def enterPreview(event):
+            if self.ui.previewButton.isEnabled(): self.ui.path.setEnabled(False)
+            event.accept()
+
+        self.ui.previewButton.leaveEvent = leavePreview
+        self.ui.previewButton.enterEvent = enterPreview
+
+        pdfviewer = config.pdfviewer
         #This also sets the right tab
         self.ui.pdf.click()
         self.ui.none.click()
@@ -648,6 +632,8 @@ class EditTab(QtGui.QScrollArea):
             raise ValueError("Not possible. One of the format radio buttons has to be clicked. Perhaps your Qt Version is different or broken.")
         return function, extension
 
+
+
     def export(self):
         """Export! button.
         Also saves paths, SplitBy and Format in the Gui session"""
@@ -661,6 +647,9 @@ class EditTab(QtGui.QScrollArea):
             process.readyReadStandardOutput.connect(lambda: self.write(str(process.readAllStandardOutput(), encoding='utf-8')))
             process.finished.connect(reset)
             process.start(string)
+            process.waitForFinished()
+            return process.exitCode()
+
 
         api.core.lilypond.callExternalCustom = startLyExportProcess
 
@@ -675,8 +664,6 @@ class EditTab(QtGui.QScrollArea):
             splitby = "exportExtractPart"
         elif self.ui.group.isChecked():
             splitby = "group"
-        elif self.ui.jackport.isChecked():
-            splitby = "jackPort"
         elif self.ui.track.isChecked():
             splitby = "_uniqueContainerName"
         else:
@@ -684,6 +671,7 @@ class EditTab(QtGui.QScrollArea):
 
         filepath = self.ui.path.currentText()
 
+        self.ui.output.clear()
         self.updatePathComboBoxSessionDatabase()
         if extension == "bin" or filepath:
             self.sysOrg = sys.stdout
@@ -697,11 +685,50 @@ class EditTab(QtGui.QScrollArea):
             self.ui.warningLabel_Lower.show()
             return False
 
+    def preview(self):
+        """Export! button.
+        Also saves paths, SplitBy and Format in the Gui session"""
+
+        def startLyExportProcess(string):
+            def reset():
+                api.core.lilypond.callExternalCustom = api.core.lilypond._callExternalCustom
+            #Override the lilypond export function in core so that exporting does not block the gui and we can route output to self.ui.output (QTextEdit)
+            process = QtCore.QProcess(self)
+            process.setProcessChannelMode(QtCore.QProcess.MergedChannels)
+            process.readyReadStandardOutput.connect(lambda: self.write(str(process.readAllStandardOutput(), encoding='utf-8')))
+            process.finished.connect(reset)
+            process.start(string)
+            process.waitForFinished()
+            return process.exitCode()
+
+        api.core.lilypond.callExternalCustom = startLyExportProcess
+
+        self.ui.warningLabel_Lower.hide()
+
+        #SplitBy radio buttons
+        if self.ui.none.isChecked():
+            splitby = None
+        elif self.ui.exportparts.isChecked():
+            splitby = "exportExtractPart"
+        elif self.ui.group.isChecked():
+            splitby = "group"
+        elif self.ui.track.isChecked():
+            splitby = "_uniqueContainerName"
+        else:
+            raise ValueError("Not possible. One of the Split By radio buttons has to be clicked. Perhaps your Qt Version is different or broken.")
+
+        self.ui.output.clear()
+        self.sysOrg = sys.stdout
+        sys.stdout = self
+        api.previewPDF(self.backendCollection, pdfviewer = config.pdfviewer, lilypondbinary = config.lilypondbinary, parts = splitby)
+        print () #a new line to make the console output nicer
+        sys.stdout = self.sysOrg
+
     def write(self, txt):
         """Emulates sys.stdout and sys.stderr behaviour.
         Write the stdout and stderror to the output text edit"""
         self.ui.output.insertPlainText(txt)
-        self.sysOrg.write(txt)
+        #self.sysOrg.write(txt)
 
     def openPathButton(self):
         doesntmatter, extension = self._getFunctionAndExtension()
