@@ -252,9 +252,10 @@ class Cursor(NestedListIter):
 
         self.flatCursorIndex = 0 #the number of items left of the cursor.
         self.upbeatTicks = 0 #the number of upbeat ticks left of the cursor
-        self._smfInstrument = []  #Track initial values
-        self._jackInstrument = []  #Track initial values
 
+        self.prevailingSmfPatch = [self.nested_list.smfPatch]   #midi pach number 0-127. no bank.
+        self.prevailingJackPatch = [self.nested_list.jackPatch]  #midi pach number 0-127. no bank
+        self.prevailingJackChannel = [self.nested_list.jackChannel[0]]  #only for jack. We are only interested in the midi note here, so we don't need the whole channel range
 
     _pitchindex = 1420 #The pitchindex is a CLASS variable. It is the same for all cursors in all tracks in all scores. In other words, a program wide state. not saved
     prevailingDot = False #For the sake of simplicity this is only a bool. No "four prevailing dots". not saved.
@@ -263,28 +264,6 @@ class Cursor(NestedListIter):
     slursOn = set([SlurOn, PhrasingSlurOn])
     slursOff = set([SlurOff, PhrasingSlurOff])
 
-    @property
-    def smfInstrument(self):
-        if self._smfInstrument:
-            return self._smfInstrument
-        else: #empty list
-            return [(self.nested_list.smfBank,self.nested_list.smfPatch)]
-    @property
-    def jackInstrument(self):
-        if self._jackInstrument:
-            return self._jackInstrument
-        else: #empty list
-            return [(self.nested_list.jackBank,self.nested_list.jackPatch)]
-
-
-    @property
-    def smfInstrument(self):
-        if self._smfInstrument:
-            return self._smfInstrument
-        else: #empty list
-            return [(self.nested_list.smfBank,self.nested_list.smfPatch)]
-
-
     @property
     def pitchindex(self):
         return Cursor._pitchindex
@@ -328,6 +307,15 @@ class Cursor(NestedListIter):
         #Formula: (ticks / denominator + 1) / nominator  = measurenumber, rest is the position in that measure.
         return divmod(self.ticksSinceLastMeasureStart / self.prevailingTimeSignature[-1].denominator, self.prevailingTimeSignature[-1].nominator)[1]
 
+    #def isMetricalStressed(self):
+    #    """Returns if this on a relatively stressed position or not.
+    #    Depends on the timesig.
+    #    Since in 4/4 a quarter on the second position is not stressed
+    #    but the beginning of an 8th pair is relatively stressed the
+    #    function also takes into account the current rhythm layer."""
+    #    self.prevailingTimeSignature[-1].denominator
+    #    return True
+
     def _is_sequence(self, item=None):
         '''Private method to test whether an item is a non-string sequence.
         If item is None, test current item.'''
@@ -384,8 +372,16 @@ class Cursor(NestedListIter):
             elif typ is Upbeat:
                 self.upbeatTicks += current_item.duration
             elif typ is InstrumentChange:
-                self._smfInstrument.append((current_item.smfBank, current_item.smfPatch))
-                self._jackInstrument.append((current_item.jackBank, current_item.jackPatch))
+                self.prevailingSmfPatch.append(current_item.smfPatch)
+                self.prevailingJackPatch.append(current_item.jackPatch)
+            elif typ is ProgramChangeAbsolute: #only for jack
+                self.prevailingJackPatch.append(current_item.number)
+            elif typ is ProgramChangeRelative: #only for jack
+                self.prevailingJackPatch[-1] += current_item.number #TODO: is this also too late, as tempoModification?
+            elif typ is ChannelChangeAbsolute: #only for jack. We are only interested in the midi note here, so we don't need the whole channel range
+                self.prevailingJackChannel.append(current_item.number)
+            elif typ is ChannelChangeRelative: #only for jack. We are only interested in the midi note here, so we don't need the whole channel range
+                self.prevailingJackChannel[-1] += current_item.number #TODO: is this also too late, as tempoModification?
 
         if not self._is_sequence(): #gather data before stepping right.
             gather(self.get_item())
@@ -462,8 +458,18 @@ class Cursor(NestedListIter):
         elif typ in self.slursOff:
             self.legato.append(True)
         elif typ is InstrumentChange:
-            self._smfInstrument.pop()
-            self._jackInstrument.pop()
+            self.prevailingSmfPatch.pop()
+            self.prevailingJackPatch.pop()
+        elif typ is ProgramChangeAbsolute: #only for jack
+            self.prevailingJackPatch.pop()
+        elif typ is ProgramChangeRelative: #only for jack
+            self.prevailingJackPatch[-1] -= current_item.number
+        elif typ is ChannelChangeAbsolute: #only for jack. We are only interested in the midi note here, so we don't need the whole channel range
+            self.prevailingJackChannel.pop()
+        elif typ is ChannelChangeRelative: #only for jack. We are only interested in the midi note here, so we don't need the whole channel range
+            self.prevailingJackChannel[-1] -= current_item.number
+        elif typ is Upbeat:
+                self.upbeatTicks -= current_item.duration
         return True
 
     def iterate(self):
@@ -474,6 +480,18 @@ class Cursor(NestedListIter):
         while self.right():
             yield self.get_item()
 
+    def rightToFirstDuration(self):
+        """A very strict function that goes right until it finds
+        an item with duration. If the current item already has duration
+        it does not move the cursor"""
+        if self.get_item().duration:
+            return True
+        while self.right(): #no fear for the end of the track
+            if self.get_item().duration:
+                return True
+        else:
+            return False
+
     def insert(self, value):
         '''Insert an item at the cursor location, which is insert-left
         If value is a sequence, cursor moves to the first toplevel
@@ -534,10 +552,10 @@ class Cursor(NestedListIter):
             self.go_to_head()
             self.resetToDefault()
 
-
-
     def delete_list(self):
         """Delete the most inner list/container.
+        aka. "Delete Container Instance"
+
         Go left until the stack[-1] is 0 and then one step more.
         Everything right of the cursor is of no interest then and we can
         delete the complete container without resetting any data.
@@ -552,8 +570,15 @@ class Cursor(NestedListIter):
             if len(self.stack) == 2: #toplevel container, directly in the track
                 ret = cont.pop(self.stack[0])
             else: #example: [4, 3, 2] so we need to delete [4,3]. [-1] does not matter, [-2] is the .pop() value and [-3] is the list to pop from.
-                ret = eval(self.createDeleteFunctionAsString(self.stack[:-1])).pop()
+                length = len(self.stack)
+                for num, coord in enumerate(self.stack): #enumerate is from 0. len is 'from' 1
+                    cont = cont[coord] #recursive
+                    if length-3 == num:
+                        ret = cont.container.pop(self.stack[-2])
+                        break
 
+
+                #ret = eval(self.createDeleteFunctionAsString(self.stack[:-1])).pop()
         self.left()
         self.right()
         self.syncTickIndex()
@@ -602,7 +627,6 @@ class Cursor(NestedListIter):
                     return False #track is shorter than ticks.
             return True
 
-
     def syncTickIndex(self):
         """Stay on the same item, but update the tickindex.
         This is used if a linked item under the cursor is not the first
@@ -628,3 +652,21 @@ class Cursor(NestedListIter):
             return self._get_item_at(temp_stack[:-1])
         else:
             return None #we are just in a track or at the start position
+
+    def beginning(self):
+        """Return all items up to the first one with duration.
+
+        Uses the cursor so we don't need to care about containers.
+        This also means the cursor will be resetted.
+        Use only when dealing with copies where you reset the cursor
+        anyway. e.g. export playback.
+
+        Use this to figure out if a tempo sig, timesig etc. was set
+        before the first real music event (note, rest etc.)"""
+        l = []
+        for i in self.iterate():
+            if i.duration:
+                return l
+            else:
+                l.append(i)
+        return [] #if only no-duration items treat this track as non-existent. Return nothing.
