@@ -46,7 +46,7 @@ def getIncludes(TEMPLATE_ROOT, USER_TEMPLATE_ROOT, COLLECTION_TEMPLATE_ROOT):
     return (lilypondtemplatenames, lilypondincludes)
 
 
-def _createProto(templateData, workspace):
+def _createProto(templateData, workspace, standaloneMode = True):
     """Replace template markers with Laborejo data.
 
     There are single markers and Collection() markers.
@@ -74,13 +74,14 @@ def _createProto(templateData, workspace):
     templateString = templateString.replace("%$$FONTSIZE$$", str(workspace.lyFontSize)) #Lilypond Fontsize from core.score
     templateString = templateString.replace("%$$LILYPONDDEFINITIONS$$", workspace.lilypondDefinitions.exportLilypond()) #Extra definitions, like Lilypond-Scheme
 
+    if not standaloneMode:
+        templateString = templateString.replace("%$$GLOBALHEADER$$", workspace.header.exportLilypond())
+
     if workspace.lastKnownFilename:
         templateString = templateString.replace("%$$FILENAME$$", workspace.lastKnownFilename)
     else:
         templateString = templateString.replace("%$$FILENAME$$", "Unsaved")
 
-    templateString = templateString.replace("%$$GLOBALHEADER$$", workspace.header.exportLilypond()) #Header data like title and composer.
-
     return templateString
 
 def _createMusicBlock(templateString, workspace, standaloneMode = True, parts = None):
@@ -97,10 +98,12 @@ def _createMusicBlock(templateString, workspace, standaloneMode = True, parts =
         #the only header data we need is global header.
         #But we need to block the extra score header block with empty data (which means empty lilypond syntax)
         #If not certain meta data will show up twice, once for the global header and once for score header.
-        templateString = templateString.replace("%$$HEADER$$", workspace.emptyHeader.exportLilypond())
+        templateString = templateString.replace("%$$HEADER$$", workspace.score.emptyHeader.exportLilypond())
+        templateString = templateString.replace("%$$GLOBALHEADER$$", workspace.score.header.exportLilypond()) #Header data like title and composer.
     else:
         #There is already a global header in place but we also need the score header because this is only a part of a core.Collection()
-        templateString = templateString.replace("%$$HEADER$$", workspace.header.exportLilypond())
+        #print ("music block header", workspace.score.header.data)
+        templateString = templateString.replace("%$$HEADER$$", workspace.score.header.exportLilypond())
 
     #Voices must be generated before container, eventhough the voices contain Container. Only by recursing through voices the container-data generation is triggered.
     templateString = templateString.replace("%$$VOICES$$",  tempScore.generateLilypondVoice()) #Score music data.
@@ -130,8 +133,12 @@ def createCollection(templateData, collection, parts):
     One before and one after the music. The whole block will be exported
     multiple times.
     """
+    #If this is a collection plus parts export we can safely edit the data directly.
+    if parts and collection.score.splitByToHeader: #during collection edit nothing is saved so we can safely modify anything. The problem is that we must set the global header to the local instrument each time.
+        collection.header.data["instrument"] = parts[1] #this needs to be done before calling createProto.
+
     #Create the basic template with all generic markers replaced
-    templateString = _createProto(templateData, collection)
+    templateString = _createProto(templateData, collection, standaloneMode = False)
 
     #Check if we have a valid template with two music markers %$$!%
     if not templateString.count("%$$!%") == 2:
@@ -156,9 +163,8 @@ def create(templateData, workspace, parts):
     core.Collection()"""
 
     #We cannot import the core module to lilypond. Thats why we are checking for the name directly.
-    try: #Py 3.2 compatibility
+    try: #Py 3.2 compatibility #TODO
         typ = type(workspace).__qualname__
-        print (repr(type(workspace)))
     except:
         typ = "Workspace"
         warnings.warn("You need Python 3.3 to export a Laborejo Collection")
@@ -191,6 +197,13 @@ def save(templateData, workspace, filepath, parts = None): #needs an instance of
     f = open(filepath, 'w')
     f.write(temp)
 
+
+def _callExternalCustom(string): #don't overwrite! don't change the name, don't change the number of arguments. External programs like the collection editor depend on that function
+    return subprocess.call(string, shell=True)
+#_callExternalCustom = lambda string: subprocess.Popen(string, shell=True) #don't overwrite!
+
+callExternalCustom = _callExternalCustom
+
 def previewPDF(templateData, workspace, lilypondbinary = None, pdfviewer = None, parts = None):
     if not pdfviewer:
         pdfviewer = "xdg-open"
@@ -201,11 +214,16 @@ def previewPDF(templateData, workspace, lilypondbinary = None, pdfviewer = None,
     tempi.write(temp)
     tempi.close()
     #     ret = os.system(lilypondbinary + ' --output=' + tempi.name + " " + tempi.name)
-    ret = subprocess.call(lilypondbinary + ' --output=' + tempi.name + " " + tempi.name, shell=True)
+
+    #ret = subprocess.call(lilypondbinary + ' --output=' + tempi.name + " " + tempi.name, shell=True)
+    programString = lilypondbinary + ' --output=' + tempi.name + " " + tempi.name
+    ret = callExternalCustom(programString)
     if ret == 0:
         subprocess.Popen(pdfviewer + " " +  tempi.name + ".pdf", shell=True)
     else:
-        raise SystemError("Error: Could not create temp file")
+        #raise SystemError("Error: Could not create temp file")
+        raise RuntimeError("Could not create lilypond output. Most likely you have Lilypond errors. Either you did override things manually or it is an inconvenience the developers can possibly solve. Please send your fail to the Laborejo team.")
+
 
 def exportLilyBin(templateData, workspace, lilybinId, parts = None):
     #TODO: lilybin.com does not support the reusing of IDs yet. But we are ready.
@@ -219,8 +237,7 @@ def exportLilyBin(templateData, workspace, lilybinId, parts = None):
     lilybinUrl = "http://www.lilybin.com/" + jsonReturnDict["id"]
     return (lilybinUrl, jsonReturnDict["id"])
 
-_callExternalCustom = lambda string: subprocess.Popen(string, shell=True) #don't overwrite!
-callExternalCustom = _callExternalCustom
+
 
 def exportPDF(templateData, workspace, filepath, lilypondbinary = None, parts = None):
     if not lilypondbinary:
@@ -1026,3 +1043,89 @@ sortedNoteNameList = [
     "bis'''''" ,
     "bisis'''''" ,
     ]
+
+
+#The lilypond chord format is notename:suffix. Eg. c:m6
+#The following list, contributed by Stjepan Horvat zvanstefan@gmail.com
+#gives us the real notes, assuming the pitch is just c.
+
+chordnamesSuffix = {
+    "dur" : "< c e g >",
+    "dim" : "< c ees ges >",
+    "m" : "< c ees g >",
+
+    #% accords 1ere tierce mineure  4 notes
+    "7dim" : "< c ees ges beses >",
+    "dim7" : "< c ees ges beses >",
+    "aug" : "< c ees gis >",
+    "m.5+" : "< c ees gis >",
+    "m6" : "< c ees g a >",
+    "m7.5" : "< c ees ges bes >",
+    "m7" : "< c ees g bes >",
+    "m7.5+" : "< c ees gis bes >",
+    "m7+" : "< c ees g b >",
+    "m5.9" : "< c ees g d' >",
+
+    #% accords 1ere tierce mineure 5 notes et +
+    "m6.9" : "< c ees g a d' >",
+    "m7.9" : "< c ees g bes des' >",
+    "m9" : "< c ees g bes d' >",
+    "m9.5" : "< c ees ges bes d' >",
+    "m9.7+" : "< c ees g b d' >",
+    "m7.9+" : "< c ees g bes dis' >",
+    "m7.11" : "< c ees g bes f' >",
+    "m7.13" : "< c ees g bes a' >",
+    "m11" : "< c ees g bes d' f' >",
+    "m11.5" : "< c ees ges bes d' f' >",
+    "m13" : "< c ees g bes d' f' a' >",
+
+    #% accords 1ere tierce majeure 3 notes
+    "dim" : "< c e ges >",
+    "aug" : "< c e gis >",
+
+    #% accords 1ere tierce majeure 4 notes
+    "6.9" : "< c e g a d' >",
+    #%accord spécial altéré
+    "7" : "< c e g bes >",
+    "8" : "< c e g bes c'>",
+    "6.9" : "< c e g a d'>",
+    "maj" : "< c e g b >",
+    "maj.5" : "< c e ges b >",
+    "maj.5+" : "< c e gis b >",
+
+    "7.5" : "< c e ges bes >",
+    "7.5+" : "< c e gis bes >",
+    "5.9" : "< c e g d' >",
+
+    #% accords 1ere tierce majeure 5 notes et +
+    "maj9" : "< c e g b d' >",
+
+    "9" : "< c e g bes des' >",
+    "9.5" : "< c e ges bes des' >",
+    "9.5+" : "< c e gis bes des' >",
+    "9.11+" : "< c e g bes d' fis' >",
+    "9+" : "< c e g bes dis' >",
+    "9+.5" : "< c e ges bes dis' >",
+    "9+.5+" : "< c e gis bes dis' >",
+
+    "7.11+" : "< c e g bes fis' >",
+    "7.13" : "< c e g bes aes' >",
+
+    "maj11" : "< c e g b d' f' >",
+
+    "maj13" : "< c e g b d' a' >",
+    "13" : "< c e g bes d' a' >",
+    "13.9" : "< c e g bes des' a' >",
+
+    #% accord sus.
+    "sus2" : "< c d g >",
+    "sus4" : "< c f g >",
+    "sus4.7" : "< c f g bes >",
+    "sus4.7.9" : "< c f g bes d' >",
+}
+
+#You cannot use the following function here because of circular dependencies.
+#But it is to fill in the untransposedChords from the api, which is happening indeed.
+#Transform the lily string dict to a laborejo pitch dict
+
+untransposedChords = {}
