@@ -357,6 +357,24 @@ def ChannelChangeAbsolute(saveStructure):
     if "number" in saveStructure[1]: new.number = saveStructure[1]["number"]
     return _return(new)
 
+def ProgramChangeRelative(saveStructure):
+    new = items.ProgramChangeRelative(currentLoadSession.currentWorkspace, )
+    addLilypond(new, saveStructure)
+    addPlayback(new, saveStructure)
+    addInternal(new, saveStructure)
+    addItem(new, saveStructure)
+    if "number" in saveStructure[1]: new.number = saveStructure[1]["number"]
+    return _return(new)
+
+def ProgramChangeAbsolute(saveStructure):
+    new = items.ProgramChangeAbsolute(currentLoadSession.currentWorkspace, )
+    addLilypond(new, saveStructure)
+    addPlayback(new, saveStructure)
+    addInternal(new, saveStructure)
+    addItem(new, saveStructure)
+    if "number" in saveStructure[1]: new.number = saveStructure[1]["number"]
+    return _return(new)
+
 def InstrumentChange(saveStructure):
     new = items.InstrumentChange(currentLoadSession.currentWorkspace, )
     addLilypond(new, saveStructure)
@@ -458,16 +476,12 @@ def Track(saveStructure):
     if "smfVolume" in saveStructure[1]: new.smfVolume = saveStructure[1]["smfVolume"]
     if "smfPan" in saveStructure[1]: new.smfPan = saveStructure[1]["smfPan"]
 
-    if "jackPort" in saveStructure[1]: new.jackPort = saveStructure[1]["jackPort"]
     if "jackChannel" in saveStructure[1]: new.jackChannel = saveStructure[1]["jackChannel"]
     if "jackPatch" in saveStructure[1]: new.jackPatch = saveStructure[1]["jackPatch"]
     if "jackBank" in saveStructure[1]: new.jackBank = saveStructure[1]["jackBank"]
     if "jackVolume" in saveStructure[1]: new.jackVolume = saveStructure[1]["jackVolume"]
     if "jackPan" in saveStructure[1]: new.jackPan = saveStructure[1]["jackPan"]
 
-    if "jackAudioReturnPortLeft" in saveStructure[1]: new.jackAudioReturnPortLeft = saveStructure[1]["jackAudioReturnPortLeft"]
-    if "jackAudioReturnPortRight" in saveStructure[1]: new.jackAudioReturnPortRight = saveStructure[1]["jackAudioReturnPortRight"]
-
     #selected items are not saved
     return new
 
@@ -480,6 +494,10 @@ def Score(saveStructure):
 
     #Score Parameters
     if "subtext" in saveStructure[1]: new.subtext = saveStructure[1]["subtext"]
+    if "splitByToHeader" in saveStructure[1]: new.splitByToHeader = saveStructure[1]["splitByToHeader"]
+
+    if "header" in saveStructure[1]: new.header = convertHeader(saveStructure[1]["header"])
+
     if "defaultPerformanceSignature" in saveStructure[1]:
         defaultSig = items.PerformanceSignature(parentWorkspace = currentLoadSession.currentWorkspace)
         addLilypond(defaultSig, saveStructure[1]["defaultPerformanceSignature"])
@@ -513,6 +531,8 @@ def addLilypond(new, saveStructure):
     if "directivePre" in saveStructure[1]: new.directivePre = saveStructure[1]["directivePre"]
     if "directiveMid" in saveStructure[1]: new.directiveMid = saveStructure[1]["directiveMid"]
     if "directivePst" in saveStructure[1]: new.directivePst = saveStructure[1]["directivePst"]
+    if "hidden" in saveStructure[1]: new.hidden = saveStructure[1]["hidden"]
+    if "transparent" in saveStructure[1]: new.transparent = saveStructure[1]["transparent"]
 
 def addInternal(new, saveStructure):
     """In place modifications to recreate Internal class info"""
@@ -532,6 +552,8 @@ def addPlayback(new, saveStructure):
     if "instructionPst" in saveStructure[1]: new.instructionPst = saveStructure[1]["instructionPst"]
     if "channelOffset" in saveStructure[1]: new.channelOffset = saveStructure[1]["channelOffset"]
     if "forceChannel" in saveStructure[1]: new.forceChannel = saveStructure[1]["forceChannel"]
+    if "programOffset" in saveStructure[1]: new.programOffset = saveStructure[1]["programOffset"]
+    if "forceProgram" in saveStructure[1]: new.forceProgram = saveStructure[1]["forceProgram"]
 
 def addPerformance(new, saveStructure):
     """In place modifications to recreate Playback class info
@@ -553,6 +575,8 @@ def addPerformance(new, saveStructure):
     if "velocityMetricalMain" in saveStructure[1]: new.velocityMetricalMain = saveStructure[1]["velocityMetricalMain"]
     if "velocityMetricalNothing" in saveStructure[1]: new.velocityMetricalNothing = saveStructure[1]["velocityMetricalNothing"]
     if "velocityMetricalSecondary" in saveStructure[1]: new.velocityMetricalSecondary = saveStructure[1]["velocityMetricalSecondary"]
+    if "swingMod" in saveStructure[1]: new.swingMod = saveStructure[1]["swingMod"]
+    if "swingLayer" in saveStructure[1]: new.swingLayer = saveStructure[1]["swingLayer"]
 
 #Main functions
 def convertLilypondDefinitions(saveStructure):
@@ -567,7 +591,7 @@ def convertLilypondDefinitions(saveStructure):
 def convertHeader(saveStructure):
     def convert(saveStructure):
         if saveStructure[0] == "Header":
-            new = items.Header()
+            new = items.Header(parentWorkspace = currentLoadSession.currentWorkspace)
             addLilypond(new, saveStructure)
             addInternal(new, saveStructure)
             if "data" in saveStructure[1]:
@@ -613,7 +637,8 @@ def addContainer(new, saveStructure):
     if "transposition" in saveStructure[1]: new.transposition = saveStructure[1]["transposition"]
 
     containerList = [] #This makes sure that all previous auto-created containers from new classes get deleted.
-    stopForTemplate = [items.SlurOff, items.SlurOn, items.MultiMeasureRest, items.Placeholder, items.Upbeat, items.Start, items.End, items.Appending] #We cant use a set because we have unhashable items.
+    stopForTemplate = [items.RepeatOpen, items.RepeatClose, items.RepeatCloseOpen, items.Segno, items.Fine, items.SlurOff, items.SlurOn, items.MultiMeasureRest, items.Placeholder, items.Upbeat, items.Start, items.End, items.Appending] #We cant use a set because we have unhashable items.
+    #goTemplate = [items.Clef, items.SpecialBarline, items.TimeSignature, items.TempoSignature, items.Upbeat, items.Markup, items.KeySignature, items.TempoModification, items.DynamicSignature, items.PerformanceSignature, items.InstrumentChange, items.ChannelChangeRelative, items.ChannelChangeAbsolute]
     global asTemplate
     currentLoadSession.currentParentContainer = new
     for item in saveStructure[1]["container"]:
@@ -623,6 +648,7 @@ def addContainer(new, saveStructure):
             #Since we stop before the end of a Track we need a custom appending
             app = items.Appending(currentLoadSession.currentWorkspace)
             containerList.append(app)
+            currentLoadSession.nonTrackContainers = {} #Delete the old containers.
             break
         containerList.append(i) #recursive call
     new.container = containerList
@@ -685,6 +711,8 @@ loadingDict =  {
             "PerformanceSignature" : PerformanceSignature ,
             "ChannelChangeRelative" : ChannelChangeRelative ,
             "ChannelChangeAbsolute" : ChannelChangeAbsolute ,
+            "ProgramChangeRelative" : ProgramChangeRelative ,
+            "ProgramChangeAbsolute" : ProgramChangeAbsolute ,
             "InstrumentChange" : InstrumentChange ,
             "SlurOn" : SlurOn ,
             "SlurOff" : SlurOff ,
@@ -735,7 +763,6 @@ def load(filepath, force = False, loadAsTemplate = False, newSession = True):
         #else:
         #    currentLoadSession.currentWorkspace = newWorkspace
         currentLoadSession.filepath = filepath
-        newWorkspace.header = convertHeader(saveStructure["header"])
         newWorkspace.lilypondDefinitions = convertLilypondDefinitions(saveStructure["lilypondDefinitions"])
         if "score" in saveStructure:
             newWorkspace.score = convert(saveStructure["score"])
@@ -743,6 +770,10 @@ def load(filepath, force = False, loadAsTemplate = False, newSession = True):
             print ("[" + currentLoadSession.filepath + "]Old save format detected. Save before editing the file to convert to new format")
             newWorkspace.score = convert(saveStructure["movement"])
 
+        if "header" in saveStructure: #The header data changed from workspace to score between 0.7 and 0.8
+            newWorkspace.score.header = convertHeader(saveStructure["header"])
+            print ("[" + currentLoadSession.filepath + "]Old save format detected. Save before editing the file to convert to new format")
+
         if "lytemplate" in saveStructure: newWorkspace.lytemplate = saveStructure["lytemplate"]
         if "ardourtemplate" in saveStructure: newWorkspace.ardourtemplate = saveStructure["ardourtemplate"]
         if "uniqueContainerNames" in saveStructure: newWorkspace.uniqueContainerNames = saveStructure["uniqueContainerNames"]
@@ -781,6 +812,9 @@ def loadMergeParts(listOfFilepaths):
     Create cursors for all new tracks.
     """
 
+    if len(listOfFilepaths) <= 1:
+        raise ValueError("loadMergeParts needs at least two files. But it was only", listOfFilepaths)
+
     typesOfPrevailingSignature = {
         items.TimeSignature: "prevailingTimeSignature",
         items.KeySignature: "prevailingKeySignature",
@@ -808,12 +842,39 @@ def loadMergeParts(listOfFilepaths):
                 item.lilypond = " "
                 item.playback = None #supresses any midi output
 
-    first = load(listOfFilepaths[0])
-
     allTracks = {} #key is the unique track name, value a list which gets expanded.
     lastCursors = {} #key is the unique track name, value the cursor.
     realAppendings = {} #key is the unique track name, value the appending of the first tracks appending which has the correct parent instances.
     lyrics = {} #key is the unique track name, value is a list of strings, each one is a verse.
+    allWorkspaces = []
+
+
+    #First load the first file. This needs to be done separately because we need to create a new session
+    first = load(listOfFilepaths[0])
+    allWorkspaces.append(first)
+
+    #Then load the other workspaces and store their tracks
+    for filepath in listOfFilepaths[1:]:
+        wsp = load(filepath, newSession = False)
+        allWorkspaces.append(wsp)
+
+    #Get all names in all listOfFilepaths
+    allAllTrackNames =  set()
+    [allAllTrackNames.update(wsp.score.allTrackNames()) for wsp in allWorkspaces]
+
+    #Add missing tracks to each file.
+    for wsp in allWorkspaces:
+        myNames = wsp.score.allTrackNames()
+        for name in allAllTrackNames:
+            if not name in myNames: #if the track does not exist, add it.
+                wsp.score.addTrack(name)
+
+
+    for wsp in allWorkspaces:
+        wsp.score.makeTracksEqualLengthWithPlaceholders()
+
+    ## Now all scores/workspaces have the same amount of tracks with the same unique names, even if they are empty. All tracks have the same lenght, per score.
+    ## We now combine these nice uniform set of scores.
 
     for cursor in first.score.cursors:
         track = cursor.nested_list
@@ -822,22 +883,18 @@ def loadMergeParts(listOfFilepaths):
         realAppendings[track.uniqueContainerName] = track.container.pop(-1) #remove appending and store it for later.
         lyrics[track.uniqueContainerName] = track.lyrics.split("\n\n")
 
-    for filepath in listOfFilepaths[1:]:
-        wsp = load(filepath, newSession = False)
+    for wsp in allWorkspaces[1:]:
         first.score.subtext += "\n" + wsp.score.subtext
         first.score.substitutions = dict(list(wsp.score.substitutions.items()) + list(first.score.substitutions.items()))
         for cursor in wsp.score.cursors:
             track = cursor.nested_list
-            if track.uniqueContainerName in allTracks:
-                name = cursor.nested_list.uniqueContainerName
-                filterTrackBeginning(cursor, lastCursors[cursor.nested_list.uniqueContainerName]) #in place filtering, see docstring
-                allTracks[track.uniqueContainerName].container += track.container[:-1] #without appending
-                lastCursors[cursor.nested_list.uniqueContainerName] = cursor
-                for index, verse in enumerate(track.lyrics.split("\n\n")):
-                    lyrics[name][index] += " " + verse
-                allTracks[name].endingBar = track.endingBar #the last one stays in.
-            else:
-                raise ValueError("all unique track names must be already in the first part")
+            name = cursor.nested_list.uniqueContainerName
+            filterTrackBeginning(cursor, lastCursors[name]) #in place filtering, see docstring
+            allTracks[name].container += track.container[:-1] #without appending
+            lastCursors[name] = cursor
+            for index, verse in enumerate(track.lyrics.split("\n\n")):
+                lyrics[name][index] += " " + verse
+            allTracks[name].endingBar = track.endingBar #the last one stays in.
 
         #Finally add the real appendings, joined lyrics etc.
         if len(filepath) > 1:
