@@ -10,10 +10,14 @@ LYRICS = False #Show the Lyrics in the GUI. Trivial setting, can be toggled at a
 DURATION_MOD = 0.15 #Default: 0.15 #Bigger means more space between all notes and objects
 MIDI_TIMER = 34 #miliseconds update period. Used for midi-in detection and playback cursor movement smoothness. Default 34 is equal to around 30 frames/updates per second. The lower it is the less latency you experience for midi in. Low values may drag down performance. Try to stay above 10ms.
 AUDIO_FEEDBACK = True #Change to False if you want to start the GUI without Audio feedback (e.g. flats/sharps, virtual Piano). Trivial setting, can be toggled at any time in the program itself.
+TRANSPORT_KEEP_ROLLING = False #True lets the jack transport system, aka playback, rolling even after the song in Laborejo is over. Trivial setting, can be toggled at any time in the program itself.
 
-lilypondbinary = "" #use the system default
-pdfviewer = "" #use the system default
-midiinport = "" #Jack Midi input port for note insert. No ALSA. Example: jack-keyboad:midi_out
+#Laborejo uses external programs for some of its functions. It has default names for these but they can be changed.
+#You can give a executable name to use a specific progra version (either in your PATH or absolute path).
+#Use an empty string "" for the default value
+lilypondbinary = "" #Default: "lilypond". Alternative example: "/usr/local/bin/lilypond"
+pdfviewer = "" #Default: "xdg-open". Alternative example: "/usr/bin/xpdf"
+midiinport = "" #Jack Midi input port for note insert. "client:port". No ALSA. Default: no connection. Alternative example: "jack-keyboad:midi_out"
 
 #Shortcuts
 shortcuts = {
@@ -91,16 +95,14 @@ shortcuts = {
 
         "F2" : "actionScript",
         "F3" : "actionView_PDF",
-        "Shift+F3" : "actionLilypond_Text",
-
-        "F4" : "actionDurationInsertMode", #that is really a toggle
+        "Shift+F3" : "actionQuick_View_PDF_Export_Group",
 
         "F5" : "actionToolbarPlayStop",
         "Ctrl+F5" : "actionToolbarPlayFromStart",
         "Shift+F5" : "actionPlaySolo",
+        "Alt+F5" : "actionPlayGroup",
         "F6" : "actionToolbarEmergencyPlaybackStop",
         "F7" : "actionToolbarJackModeToggle",
-        "Ctrl+F7" : "actionRebind_external_Jack_Midi_connections",
         "F8" : "actionMIDI_Note_Entry",
 
         #Navigation
@@ -142,8 +144,11 @@ shortcuts = {
         "Shift+Return" : "actionAdd_Octave_to_Chord",
         "Shift+Delete" : "actionRemove_Note_from_Chord",
 
-        "-" : "actionSharp",
-        "+" : "actionFlat",
+        "+" : "actionSharp",
+        "-" : "actionFlat",
+        "?" : "actionReminder",
+        #"Shift+#" : "actionCautionary",
+        #Beware of the + and - keys. Locale Alert!
         #"Alt+-" : "", reserved for micro-tonality
         #"Alt++" : "", reserved for micro-tonality
 
@@ -190,12 +195,12 @@ shortcuts = {
         "Ctrl++" : "actionZoom_In",
         "Ctrl+-" : "actionZoom_Out",
         "F1" : "actionSmall_Terminal",
-        "Ctrl+P" : "actionVirtual_Piano",
 
         #Container
         #"Alt+Shift+Page Up" : "actionDelete_Current_Track",
         #"Alt+Shift+Page Down" : "actionAdd_Track",
         "Insert" : "actionInsert_Empty_Container",
+        "Shift+Insert" : "actionInsert_Existing_Container",
         "Alt+Insert" : "actionEdit_Container_Content",
         "Alt+Page Up" : "actionMove_Track_Up",
         "Alt+Page Down" : "actionMove_Track_Down",
@@ -234,13 +239,18 @@ shortcuts = {
         "," : "actionStaccato",
         "_" : "actionTenuto",
         "x" : "actionFree_Text",
-        "j" : "actionJoin_to_Cursor",
-        "Shift+j" : "actionJoin_to_Chord",
+        "j" : "actionJoin_to_Chord_prevalent_duration",
+        "Shift+j" : "actionJoin_to_Chord_sum_durations",
         "z" : "actionSustain_Change_non_print",
         "Shift+z" : "action_Sustain_On",
         "Alt+z" : "action_Sustain_Off",
         "Alt+E" : "actionFull_Dual_Ending_Sequence",
 
+        #Advanced
+        "h": "actionToggleTransparent",
+        "Alt+h" : "actionToggleHidden",
+        "Shift+h" : "actionCleanHiddenTransparent",
+
         #Force new duration emacs shortcut
         "0, ., 1" : "lambda: api.putDurations(4*384, dots = 1)",
         "0, ., 2" : "lambda: api.putDurations(2*384, dots = 1)",
@@ -361,12 +371,8 @@ palettes = {
         },
 
     "midi fine tuning": {
-        "title": "Midi Tuning",
+        "title": "Fine Tuning",
         "shortcut" : "Alt+R",
-        0:("actionChannel_Clear", "Ch clear", _("Clear Channel Offset"), ""),
-        1:("actionChannel_Minus", "Ch-", _("Channel Offset +1"), ""),
-        2:("actionChannel_Force", "Ch?", _("Force Channel"), ""),
-        3:("actionChannel_Plus", "Ch+", _("Channel Offset -1"), ""),
         4:("actionChord_Duration_Factor_Minus", "↤", _("Less Duration (shorter)"), ""),
         5:("actionChord_Duration_Factor_Reset", "✗", _("Reset Duration Finetuning"), ""),
         6:("actionChord_Duration_Factor_Plus", "↦", _("More Duration (longer)"), ""),
@@ -374,6 +380,28 @@ palettes = {
         8:("actionChord_Velocity_Factor_Reset", "✗", _("Reset Velocity Finetuning"), ""),
         9:("actionChord_Velocity_Factor_Plus", "↥", _("More Velocity (louder)"), ""),
         },
+
+
+    "channels and programs": {
+        "title": "Chan + Prog",
+        0:("actionChannel_Clear", "Ch clear", _("Clear Channel Offset"), ""),
+        1:("actionChannel_Minus", "Ch-", _("Channel Offset +1"), ""),
+        2:("actionChannel_Force", "Ch?", _("Force Channel"), ""),
+        3:("actionChannel_Plus", "Ch+", _("Channel Offset -1"), ""),
+        8:("actionProgram_Clear", "PrX", _("Clear Program Offset"), ""),
+        4:("actionProgram_Minus", "Pr-", _("Program Offset +1"), ""),
+        5:("actionProgram_Force", "Pr?", _("Force Program"), ""),
+        6:("actionProgram_Plus", "Pr+", _("Program Offset -1"), ""),
+
+        },
+
+    "playback effects": {
+        "title": "Effects",
+        0:("actionClean_Tremolo", "Clear", _("Clear Tremolo"), ""),
+        1:("actionTremolo_in_Two", "Trm2", _("Tremolo in two"), ""),
+        2:("actionCustom_Tremolo", "Trm?", _("Custom Tremolo"), ""),
+        3:("actionTremolo_in_Four", "Trm4", _("Tremolo in four"), ""),
+        },
 }
 
 midiCCShortcuts = {
