@@ -31,6 +31,7 @@ class Pseudo(object):
         self.cachedBaseDuration = 0
         self.group = 0
         self.data = False
+        self.dataOrg = False
         self.cachedMinMax = [float("inf"), -1 * float("inf")] #out of range for any pitch.
         self.data = self
         self.noteheads = False
@@ -83,11 +84,13 @@ class GuiIncipit(QtGui.QGraphicsItemGroup):
         self.addToGroup(self.nameMarker)
         self.nameMarker.setParentItem(self)
         self.nameMarker.setPos(5,0)
+        self.nameMarker.setDefaultTextColor(QtGui.QColor("black"))
         self.changeNameMarker()
 
         #Lilypond Group Marker
         self.lilypondGroupMarkers = []
         self.changeLilypondStaffGroupMarkers()
+        self.updateMarkerSize()
 
     def stringToColor(self, st):
         """Convert a string to QColor. Same string, same color
@@ -109,6 +112,7 @@ class GuiIncipit(QtGui.QGraphicsItemGroup):
                 marker = QtGui.QGraphicsTextItem(")")
                 marker.setParentItem(self)
                 marker.setScale(3)
+                marker.setDefaultTextColor(QtGui.QColor("black"))
                 self.addToGroup(marker)
                 marker.translate(0, 25)
                 self.lilypondGroupMarkers.append(marker)
@@ -116,6 +120,7 @@ class GuiIncipit(QtGui.QGraphicsItemGroup):
                 marker = QtGui.QGraphicsTextItem(self.glyphes[v])
                 marker.setParentItem(self)
                 marker.setScale(3.5)
+                marker.setDefaultTextColor(QtGui.QColor("black"))
                 self.addToGroup(marker)
                 self.lilypondGroupMarkers.append(marker)
 
@@ -125,6 +130,10 @@ class GuiIncipit(QtGui.QGraphicsItemGroup):
                 x.setPos(offset, -39)
                 offset -= 7
 
+    def updateMarkerSize(self):
+        height = 101 if self.guiTrack.dualView else 41
+        self.backendGroupMarker.setRect(0, 0, 9, height)
+
     def changeGroupColor(self):
         self.cachedGroupColor = self.stringToColor(self.data.group)
         self.backendGroupMarker.setBrush(self.cachedGroupColor)
@@ -139,6 +148,7 @@ class GuiTrack(QtGui.QGraphicsItemGroup):
 
     def __init__(self, workspace, backendTrack):
         super(GuiTrack, self).__init__()
+        self.dualView = False
         self.data = backendTrack
         self.incipit = GuiIncipit(self)
         self.leftPart = deque([])
@@ -159,7 +169,15 @@ class GuiTrack(QtGui.QGraphicsItemGroup):
         self.size = TRACK_SIZE #Y Dimension
         self.cachedTrackWidth = 0 #in pixel
         self.collapsed = False
-        self.dualView = False
+
+
+        #The data set determines where ledger lines up and down start and where they will be drawn.
+        #The first two are start under and start above. They are the graphical positioning above/below the track of the first ledger line. 10 points is one step from line to line.
+        #The second two are the boundary. If the note is below/above that we start drawing ledger lines. These are not pixels but pitch units. Or better: minMax units
+        #start_under, start_above, lower_boundary, upper_boundary, offset_below, offset_above, middle_line_special = ledgerLinesDataSet
+        self.ledgerLinesDataSetSingleView = (50, -10, 23, -33, 0, 0, False)
+        self.ledgerLinesDataSetDualView = (50+60, -10, 23+60, -33, -5.8, 0, True)
+        self.ledgerLinesDataSetCurrent = self.ledgerLinesDataSetSingleView
 
     @property
     def offsetFactor(self):
@@ -169,21 +187,23 @@ class GuiTrack(QtGui.QGraphicsItemGroup):
         return collapsedFactor * dualFactor
 
     def toggleDualView(self):
-        """A Gui-Only mode that shows one system with 11 lines.
-        The middle line is grey and is the middle c' in both violin and
-        bass clef (if the main clef is a violin clef anyway.)
+        """A Gui-Only mode that shows one system with 11 lines. The
+        middle line is invisible and is the middle c' in both violin
+        and bass clef (if the main clef is a violin clef anyway.)
         But it is not dependent on clefs. Everything works normally.
-
-        Technically you just get more lines and space so that ledger
-        lines are easier to see."""
+        Technically you just get more lines and space so that
+        ledger lines are easier to see."""
 
         if self.dualView:  #we are already in Dual Mode
             self.dualView = False
+            self.ledgerLinesDataSetCurrent = self.ledgerLinesDataSetSingleView
         else:
             #self.offset = TRACK_SIZE + TRACK_SIZE/5 #double size plus space for one more line.
             self.dualView = True
+            self.ledgerLinesDataSetCurrent = self.ledgerLinesDataSetDualView
         self.drawLines(self.cachedTrackWidth)
         self.drawLyrics()
+        self.incipit.updateMarkerSize()
         self.updateBarlines()
         self.workspace.main.ui.actionToggle_Extended_Track_View.setChecked(self.dualView)
         self.workspace.repositionTracks()
@@ -596,7 +616,9 @@ class GuiTrack(QtGui.QGraphicsItemGroup):
             tmp = self.workspace.tracks[:]
             tmp.remove(self)
             for tr in tmp:
-                tr.updateRightFromTickindexOnlyNewDisplacement(updateAllOther)
+                #TODO:  updateRightFromTickindexOnlyNewDisplacement is more performant (unmeasured, so it is a guess). But is inaccurate because it does not get the correct starting point when inserting new items in a track so that the discplament items moves to the right.
+                #tr.updateRightFromTickindexOnlyNewDisplacement(updateAllOther)
+                tr.updateRightFromTickindexOnlyNewDisplacement(0)
 
         wholeLength = positionUntilNow + self.workspace.getDisplacement(positionUntilNow, includeSelf = True)
         self.drawLines(end = wholeLength)
@@ -632,7 +654,11 @@ class GuiTrack(QtGui.QGraphicsItemGroup):
             #The cachedTimesigs stored their beginning, but not their ending. We skip the first round and then use lastRoundTimesig and not the current one. The current one indicates the end timesig.
             #timesiglist = sorted([(v,k.data) for k,v in self.cachedTimeSignatures.items()])  #create a list which is sorted after their tickindex which is [n][0]. [n][1] is the backend timesignature
             #timesiglist = sorted([(v[0],v[1], k.data) for k,v in self.cachedTimeSignatures.items()], key=lambda x: x[0])  #create a list which is sorted after their tickindex which is [n][0]. [n][1] is the backend timesignature . v[0] is the tickPositon  v[1] the index as item count
-            timesiglist = sorted((v[0],v[1], k.data) for k,v in self.cachedTimeSignatures.items())  #create a list which is sorted after their tickindex which is [n][0]. [n][1] is the backend timesignature . v[0] is the tickPositon  v[1] the index as item count
+            #timesiglist = sorted((v[0],v[1], k.data) for k,v in self.cachedTimeSignatures.items())  #create a list which is sorted after their tickindex which is [n][0]. [n][1] is the backend timesignature . v[0] is the tickPositon  v[1] the index as item count
+            #The version above, without key=, can't handle two timesigs in a row. Probably I should filter them out first?
+            #TODO: but we had that version already. Why was that commented out and replaced without a non-key version?
+            timesiglist = sorted(((v[0],v[1], k.data) for k,v in self.cachedTimeSignatures.items()), key=lambda x: x[0])  #create a list which is sorted after their tickindex which is [n][0]. [n][1] is the backend timesignature . v[0] is the tickPositon  v[1] the index as item count
+
 
             #IF SOMETHING IS WRONG WITH THE BARLINES PRINT OUT THE TIMESIGLIST!
 
