@@ -169,20 +169,59 @@ barlines = defaultdict(barlinesMissing,
 
 voicePresets = ["", "voiceOne", "voiceTwo", "voiceThree", "voiceFour", "oneVoice",]
 
+didYouKnow = [
+    #Make the first three words matter!
+    #Do not start them all with "You can..." or "...that you can", in response to the Did you know? title.
+    _("You can find help within the <a href='http://laborejo.org/Support_and_Community'>Laborejo Communiy</a>"),
+    _("<p>Most commands work in the appending position (last position in a track) and apply to the item before it.</p><p>Use it to apply dots, sharps and flats on the item you just inserted without moving the cursor back and forth.</p>"),
+    _("<p>Learn the keyboard shortcuts! Laborejo is designed to work with the keyboard alone and with midi instruments for full speed.</p>Everytime you grab your mouse you loose concentration, precision and time."),
+    _("<p>Create multi-voice staffs by adding multiple Tracks and activate the 'Merge with Above' checkbox in the track properties print section.</p><p>You better set a Voice Preset (same section) if you use merging, too.</p>"),
+    _("<p>The Track Properties are a powerful tool. Make sure to learn all sub-sections.</p><p>However, if you need the screen-space hide them with Ctrl+E (View Menu)</p>"),
+    _("<p>Set the unique track name (ID) to 'master' and everything in this track will be used by any track.</p> Use it for repeats, tempo signatures etc."),
+    _("<p>Begin a textfield, like the metadata or a Tracks instrument name, with Lilyponds \\markup syntax for advanced Lilypond formating:</p><pre>\\markup { \"Hello\" \\sharp \"World\" }</pre>"),
+    _("<p>The \"gaming cursor keys\" W, A, S, D are used to modify existing notes.</p><p>A+D (\"left/right\") to augment or diminish notes</p><p>W+S (\"up/down\") to shift them in scale. Hold Shift for shifting in octaves</p>"),
+    _("<p>Laborejo itself does not show the final output.</p><p>Use PDF Preview (F3) or Export (File->Export) to see how it really looks.</p>"),
+    _("<p>There is a custom export dialog in File->Export that lets you create several PDFs for individual instruments and groups</p>"),
+    _("<p>Zoom with Ctrl+Mousewheel or Ctrl with Plus and Minus.</p><p>Spread/shrink the space between notes by additionaly holding the Shift key.</p>"),
+    _("<p>To look around drag the screen with the middle mouse button (wheel) pressed down.</p>"),
+    _("<p>Scrolling the score can be done by using Alt+Mousewheel.</p>"),
+    _("<p>Temporary Shortcuts (until you close the program) can be created by hovering the mouse cursor over a menu entry and pressing a free key.</p><p>F9, F10, F11, F12 will be always free for hover shortcuts</p>"),
+    _("<p>Most commands can be applied to single notes and selections equally.</p><p>Use Shift + movement-keys or the mouse rubber band to create selections.<br>Deselect with the Space Bar.</p>"),
+    _("<p>There are two sets playback settings: Internal for convenience & rapidity and JACK midi for professional production.</p><p>You can switch at any time between with the toolbar-button</p>"),
+    _("<p>Start Laborejo through the command line and use parameters. Check:</p><p><pre>./laborejo-qt --help</pre></p>"),
+    _("<p>Every lbjs score is also a template for a new score.</p><p>Use File->Open as Template</p>"),
+    _("<p>Return to the notation view at any time by pressing Escape.</p>Use this to return from editing Track Properties"),
+    _("<p>There are no empty measures / bars.</p><p>Use Multi Measure Rests, Skips or Placeholders (Alt+M) instead</p>"),
+    _("<p>Most keyboard shortcuts follow a pattern:</p><p>Normal key inserts or toggles.</p><p>Together with Shift it is a variant or cleans.</p><p>With Alt you get a GUI dialog with more options.</p>"),
+    _("<p>For transposing instruments it is best practice to enter all notes into Laborejo how they should sound in the end.</p><p>Use the track properties transposition setting for the printout.</p>"),
+    _("<p>The numpad palette is a powerful tool!</p><p>Trigger the commands by pressing the matching key from the numpad layout</p><p>Cycle through the palette with Numpad-Plus and -Minus</p>"),
+    _("<p>Begin a track in the middle of a measure/bar by inserting Objects->Upbeat (Shortcut: u)</p>"),
+    _("<p>For voltas aka. multiple endings just insert a Full Ending Sequence (Alt+E) and edit.</p><p>Don't fiddle around by constructing multiple endings manually.</p>"),
+    _("<p>Use Repeats for the big structure(> 8 bars)</p></p>Containers for medium sized snippets (1-8 bars) or disconnected repeats (e.g. refrains)</p><p>Substitutions are good for micro-repeats, ornaments and patterns</p>"),
+    _("<p>Most objects can be made transparent or hidden (for educational worksheets). Use the H key alone or with Shift and Alt.</p><p>Use Objects->Print/Lilypond to hide entire sections</p>"),
+    _("<p>Toggle the insert mode to choose durations instead of inserting them (F4, Insert Mode menu).</p><p>You'll need this for MIDI input</p>"),
+    _("<p>Override any objects Lilypond output code completely with<br><pre>Advanced->Lilypond Directives->Edit Lilypond</pre></p><p>Insert a blank item with Advanced->Insert Blank Item to create your custom Lilypond objects.</p>"),
+    _("<p>Hide a track completely through Track Properties' Print section: 'Don't Print'</p><p>Use this to create playback only tracks.</p>"),
+    ]
+
+
 menus = {
     #self is the gui main.
     #in lambda functions it is "main."
 
     #Toolbar Only
-    "actionToolbarPlayStop" : "lambda: api.play(jackMode = config.JACKMODE)",
-    "actionToolbarPlayFromStart" : "lambda: api.play(startTick=0, jackMode = config.JACKMODE)",
+    "actionToolbarPlayStop" : "lambda: api.play(jackMode = config.JACKMODE, keepRolling = config.TRANSPORT_KEEP_ROLLING)",
+    "actionToolbarPlayFromStart" : "lambda: api.play(startTick=0, jackMode = config.JACKMODE, keepRolling = config.TRANSPORT_KEEP_ROLLING)",
     "actionToolbarEmergencyPlaybackStop" : "api.stop",
     "actionToolbarUnsetSoloMute" : "api.unsetSoloMute",
-    "actionPlaySolo" : "lambda: api.playCurrentTrack(jackMode = config.JACKMODE)",
+    "actionPlaySolo" : "lambda: api.playCurrentTrack(jackMode = config.JACKMODE, keepRolling = config.TRANSPORT_KEEP_ROLLING)",
+    "actionPlayGroup" : "lambda: api.playCurrentGroup(jackMode = config.JACKMODE, keepRolling = config.TRANSPORT_KEEP_ROLLING)",
     "actionToolbarJackModeToggle" : "self.toggleJackMode",
+    "actionToolbarJackTransportKeepRolling" : "self.toggleJackTransportKeepRolling",
 
     #File
     "actionView_PDF": "self.previewPDF",
+    "actionQuick_View_PDF_Export_Group": "self.previewPDFSingle",
     "actionNew": "api.new",
     "actionOpen": "self.load",
     "actionOpen_Collection": "self.loadCollection",
@@ -216,7 +255,6 @@ menus = {
     "actionLilypond_Text" : "self.viewLilypondText",
     "actionSmall_Terminal" : "self.toggleSmallTerminal",
     "actionBarlines" : "self.toggleBarlines",
-    "actionVirtual_Piano" : "self.toggleVirtualPiano",
 
     #View. Per Score.
     "actionZoom_In" : "lambda: main.session.currentGuiWorkspace.zoomIn()",
@@ -234,7 +272,6 @@ menus = {
     "actionInvert_Collapsing" : "lambda: main.session.currentGuiWorkspace.invertCollapsing()",
 
     #Mode
-    "actionDurationInsertMode" : "self.toggleMode",
     "actionMIDI_Note_Entry" : "api.jackMidiInToggleMute",
 
     #Edit
@@ -275,6 +312,7 @@ menus = {
     "actionClear_All_Groupings": "api.groupDeleteAll",
 
     "actionInsert_Empty_Container": "api.insertContainer",
+    "actionInsert_Existing_Container": "api.guiChooseContainer",
     "actionDelete_Container_Instance": "api.deleteContainerInstance",
     "actionEdit_Container": "api.editContainer",
     "actionEdit_Container_Content": "self.editContainerContent",
@@ -336,6 +374,7 @@ menus = {
     "actionTremolo_in_Two": "lambda: api.tremolo(2)",
     "actionTremolo_in_Four": "lambda: api.tremolo(4)",
     "actionCustom_Tremolo": "api.tremolo",
+    "actionClean_Tremolo": "lambda: api.tremolo(1)",
         #NotePitch
     "actionAdd_Note_to_Chord": "api.addCursorNoteToChord",
     "actionRemove_Note_from_Chord": "api.deleteCursorNote",
@@ -352,8 +391,9 @@ menus = {
     "actionShift_Note_Octave_Up": "api.shiftNoteOctaveUp",
     "actionShift_Note_Octave_Down": "api.shiftNoteOctaveDown",
 
-    "actionSharp": "api.flatten",
-    "actionFlat": "api.sharpen",
+    "actionSharp": "api.sharpen",
+    "actionFlat": "api.flatten",
+
     "actionReminder": "api.toggleNoteReminderAccidental",
     "actionCautionary": "api.toggleNoteCautionaryAccidental",
     "actionSuggestion_Accidentals_On": "api.insertSuggestedAccidentalsStyleOn",
@@ -361,8 +401,9 @@ menus = {
     "actionEnharmonic_Sharp": "api.noteEnharmonicSharp",
     "actionEnharmonic_Flat": "api.noteEnharmonicFlat",
 
-    "actionJoin_to_Cursor": "api.joinToCursorNote",
-    "actionJoin_to_Chord": "api.joinToChord",
+
+    "actionJoin_to_Chord_prevalent_duration": "api.joinToChordPrevalentDurations",
+    "actionJoin_to_Chord_sum_durations": "api.joinToChordSumDurations",
     "actionTranspose": "api.transpose",
     "actionMirror": "api.mirror",
 
@@ -566,7 +607,17 @@ menus = {
     "actionSostenuto_On": "api.insertPedalSostenutoOn",
     "actionSostenuto_Off": "api.insertPedalSustainChange",
 
+        #Print / Lilypond
+    "actionHide_Notes_Start" : "api.insertHideNotesOn",
+    "actionHide_Notes_Stop" : "api.insertHideNotesOff",
+    "actionHide_Barlines_Start" : "api.insertHideBarlinesOn",
+    "actionHide_Barlines_Stop" : "api.insertHideBarlinesOff",
+
+
     #Menu Advanced
+    "actionToggleHidden": "api.toggleHidden",
+    "actionToggleTransparent": "api.toggleTransparent",
+    "actionCleanHiddenTransparent": "api.cleanHiddenTransparent",
 
         #Substitutions
     "actionCreate_Substitutions_from_File": "self.substitutionsScoreFromFile",
@@ -591,6 +642,9 @@ menus = {
     #TODO: actionEdit_Note_Directives
     "actionClear_Notes_Directives": "api.deleteAllNoteDirectives",
 
+        #Debug and Test
+    "actionReset_and_Redraw_GUI" : "lambda: main.session.currentGuiWorkspace.fullReload()",
+
         #Rearrange
     "actionReverse": "api.rearrangeReverse",
     "actionReverse_Pitch": "api.reversePitch",
@@ -603,6 +657,7 @@ menus = {
     "actionAutoChange": "api.experimental_addAutoChange",
     "actionSplitChordTrackToVoices": "api.experimental_splitChordTrackToSingleVoiceTrack",
     "actionSpeedUpPlayback": "lambda: api.scaleTempo(2)",
+    "actionExtract_and_render_chordsymbols_to_a_new_track_with_real_chords": "api.extractAndRenderChordSymbols",
 
         #Midi
     "actionEdit_Default_Performance_Signature": "lambda: api.editPerformanceSignature(default=True)",
@@ -613,6 +668,14 @@ menus = {
     "actionChannel_Clear"  : "api.smfChannelReset",
     "actionChannel_Change_Relative"  : "api.insertChannelChangeRelative",
     "actionChannel_Change_Absolute"  : "api.insertChannelChangeAbsolute",
+
+    "actionProgram_Plus" : "api.smfProgramPlus",
+    "actionProgram_Minus" : "api.smfProgramMinus",
+    "actionProgram_Force"  : "api.smfProgramForce",
+    "actionProgram_Clear"  : "api.smfProgramReset",
+    "actionProgram_Change_Relative"  : "api.insertProgramChangeRelative",
+    "actionProgram_Change_Absolute"  : "api.insertProgramChangeAbsolute",
+
     "actionChord_Duration_Factor_Plus"  : "api.durationFactorPlus",
     "actionChord_Duration_Factor_Minus"  : "api.durationFactorMinus",
     "actionChord_Duration_Factor_Reset"  : "api.resetDurationFactor",
@@ -620,9 +683,6 @@ menus = {
     "actionChord_Velocity_Factor_Minus"  : "api.velocityFactorMinus",
     "actionChord_Velocity_Factor_Reset"  : "api.resetVelocityFactor",
 
-        #JackMidi System
-    "actionRebind_external_Jack_Midi_connections"  : "api.restoreJackConnections",
-
         #Trigger
     "actionEdit_Trigger"  : "api.editTrigger",
     "actionClear_Trigger_from_Item"  : "api.triggerDelete",
@@ -634,6 +694,8 @@ menus = {
 
     #TODO: this is only a placeholder. Replace when we get either a nice keyboard/shortcut manager or a nicer "Did you know...?" widget?
     "actionManual" : ("lambda: fedit({}, 'Manual', '<p><b>Keys</b></p> <p>Movement<ul>  <li>Cursor Keys - Move Cursor</li> <li>Ctrl and Cursor Keys - Move measure right/left or Octave up/down</li> <li>Home - Move to track beginning</li> <li>End - Move to track end</li> <li>Page Up/Down - Move Track up or down.</li> </ul>  Any movement can be combined with the \"Shift\" Key to create a selection.</p> <p> Notes and Pitches<ul> <li>1...9 insert Note durations (1 = whole, 2 = quarter ... until 6 = Breve, 7 = Longa)</li> <li>Shift and Number - Same as above, but as rest</li> <li>Alt and Number - Choose Prevailing Duration </li> <li>Alt and Shift and Number - Insert invisible rest </li> </ul> </p>')"),
+    "actionDid_you_know" : "self.showDidYouKnow",
+
 
     #Toolbar
     "actionToolbarClefTreble" : "api.insertClefTreble",
@@ -657,11 +719,4 @@ menus = {
     "actionToolbarEighthRest" : "api.insertRest8",
     "actionToolbarSixteenthRest" : "api.insertRest16",
     "actionToolbarToggleDot" : "api.dotToggle",
-        #Dynamics
-    "actionToolbarPianissimo" : "api.insertDynamicPP",
-    "actionToolbarPiano" : "api.insertDynamicP",
-    "actionToolbarMezzoPiano" : "api.insertDynamicMP",
-    "actionToolbarMezzoForte" : "api.insertDynamicMF",
-    "actionToolbarForte" : "api.insertDynamicF",
-    "actionToolbarFortissimo" : "api.insertDynamicFF",
 }
