@@ -53,8 +53,6 @@ __license__ = __doc__
 
 DEBUG = False
 
-
-
 import sys
 STDERR = sys.stderr
 
@@ -72,7 +70,8 @@ from PyQt4.QtGui import (QWidget, QLineEdit, QComboBox, QLabel, QSpinBox,
                          QColorDialog, QPixmap, QTabWidget, QApplication,
                          QStackedWidget, QDateEdit, QDateTimeEdit, QFont,
                          QFontComboBox, QFontDatabase, QGridLayout,
-                         QDoubleValidator, QPlainTextEdit)
+                         QDoubleValidator, QPlainTextEdit, QCompleter,
+                         QTextEdit)
 from PyQt4.QtCore import (Qt, SIGNAL, SLOT, QSize, #QString,
                           pyqtSignature, pyqtProperty)
 import datetime
@@ -237,14 +236,19 @@ def is_edit_valid(edit):
     return 2 #state == QDoubleValidator.Acceptable
 
 class FormWidget(QWidget):
-    def __init__(self, data, comment="", parent=None): #Data is a dict. {key:tuplet(label, default-value)}. Default-Value also defines the type of widget created. Integer creates a number-field, string a textfield etc.
+    def __init__(self, data, comment="", parent=None, autocomplete=[]): #Data is a dict. {key:tuplet(label, default-value)}. Default-Value also defines the type of widget created. Integer creates a number-field, string a textfield etc.
         QWidget.__init__(self, parent)
         from copy import deepcopy
         self.data = deepcopy(data)
         self.widgets = []
         self.formlayout = QFormLayout(self)
+        self.autocomplete = autocomplete
         if comment:
-            self.formlayout.addRow(QLabel(comment))
+            commentLabel = QLabel(comment)
+            commentLabel.setOpenExternalLinks(True)
+            if commentLabel.text().startswith("<"):
+                commentLabel.setTextFormat(Qt.RichText)
+            self.formlayout.addRow(commentLabel)
             self.formlayout.addRow(QLabel(" "))
         if DEBUG:
             print("\n"+("*"*80))
@@ -273,13 +277,27 @@ class FormWidget(QWidget):
                 continue
             elif label is None:
                 # Comment
-                self.formlayout.addRow(QLabel(value))
+                lab = QLabel(value)
+                lab.setOpenExternalLinks(True)
+                self.formlayout.addRow(lab)
                 self.widgets.append(None)
                 continue
             elif tuple_to_qfont(value) is not None:
                 field = FontLayout(value, self)
             elif text_to_qcolor(value).isValid():
                 field = ColorLayout(QColor(value), self)
+            elif self.autocomplete and type(value) is str:  #A line-edit with auto-complete
+                field = QLineEdit(value, self)
+                field.setCompleter(QCompleter(self.autocomplete,field))
+                field.selectAll()
+
+                allAutocomplete = QTextEdit("<br>".join(self.autocomplete))
+                allAutocomplete.setReadOnly(True)
+                allAutocomplete.setFocusPolicy(0) #no focus.
+                allAutocomplete.setLineWrapMode(0) #no wrap
+                allAutocomplete.setTextInteractionFlags(Qt.NoTextInteraction) #no text interaction.
+                self.formlayout.addRow(allAutocomplete)
+
             elif label == "" and isinstance(value, str):  #this comes before the generic string test.
                 field = QPlainTextEdit(value, self)
                 field.selectAll()
@@ -427,7 +445,7 @@ class FormTabWidget(QWidget):
 class FormDialog(QDialog):
     """Form Dialog"""
     def __init__(self, data, title="", comment="",
-                 icon=None, parent=None, apply=None):
+                 icon=None, parent=None, apply=None, autocomplete=[]):
         QDialog.__init__(self, parent)
 
         self.apply_callback = apply
@@ -438,7 +456,7 @@ class FormDialog(QDialog):
         ##elif len(data[0])==3: #What has a length of three?
         #   self.formwidget = FormComboWidget(data, comment=comment, parent=self)
         else: #Normal dict
-            self.formwidget = FormWidget(data, comment=comment, parent=self)
+            self.formwidget = FormWidget(data, comment=comment, parent=self, autocomplete=autocomplete)
 
         layout = QVBoxLayout()
         layout.addWidget(self.formwidget)
@@ -493,7 +511,7 @@ class FormDialog(QDialog):
         return self.data
 
 
-def fedit(data, title="", comment="", icon=None, parent=None, apply=None):
+def fedit(data, title="", comment="", autocomplete=[], icon=None, parent=None, apply=None):
     """
     Create form dialog and return result
     (if Cancel button is pressed, return None)
@@ -527,7 +545,7 @@ def fedit(data, title="", comment="", icon=None, parent=None, apply=None):
     if QApplication.startingUp():
         _app = QApplication([])
 
-    dialog = FormDialog(data, title, comment, icon, parent, apply)
+    dialog = FormDialog(data, title, comment, icon, parent, apply, autocomplete=autocomplete)
     if dialog.exec_():
         return dialog.get()
 
