@@ -188,7 +188,7 @@ class GuiItem(QtGui.QGraphicsItemGroup):
     #class GuiItem(QtGui.QGraphicsItem):
     #http://www.riverbankcomputing.co.uk/static/Docs/PyQt4/html/qgraphicsitemgroup.html#details
     """Base item group. Can hold several glyphs."""
-    def __init__(self, backendItem, displacement = 0, mainGlyph = None, mainGlyphShift = 0, fontScale = 1, forceSigs = None): #forceSigs is important for non-cursor input like Container
+    def __init__(self, backendItem, displacement = 0, mainGlyph = None, mainGlyphShift = 0, fontScale = 1, forceSigs = None, parentTrack = None): #forceSigs is important for non-cursor input like Container
         super(GuiItem, self).__init__()
         self.breakClefLoop = False #instead of typesetting this is a break marker when track.clefUpdate() runs.
         self.breakKeysigLoop = False #instead of typesetting this is a break marker when track.keysigUpdate() runs.
@@ -216,7 +216,7 @@ class GuiItem(QtGui.QGraphicsItemGroup):
             self.cachedKeysigData = forceSigs[2]
             self.cachedTimesigData = forceSigs[3]
         else: #insert on the cursor position. Safely use the backend data and wait for track.insert() to set the rest.
-            self.track = None #I am in that track. This is always unique. Even cut and paste in the backend is a delete and insert new in Laborejo. But it only valid from track.insert on because on creation it has no position in a track. So it is set in track.insert
+            self.track = parentTrack #I am in that track. This is always unique. Even cut and paste in the backend is a delete and insert new in Laborejo. But it only valid from track.insert on because on creation it has no position in a track. So it is set in track.insert
             nowClef = api._getClef() #only for init. On item creation/insert.
             self.cachedClefPitch = dictionaries.clefs[nowClef.clefString + nowClef.octave][1] #Only for GuiChord. But prevents typechecking on update. Just save the number value. Will be much faster than accessing an instance var each time. Will also be much faster when updating a whole track if a clef is changed in front. It just needs to get the number once and then save it in any GuiChord item.
             self.cachedKeysigData = api._getKeysig() #A Backend keysig.
@@ -232,6 +232,8 @@ class GuiItem(QtGui.QGraphicsItemGroup):
         self.lastPassWasGroup = False #addition to self.group. Indicates if the stem/flag needs updating at all. if group and lastPassWasGroup are both false there is not even the need to delete and redraw the stem.
         self.widthDependentOnDisplacement = False  #widthDependentOnDisplacement is for intransparent containers that need to change if a disp. item is in the other track.
 
+        self.hiddenCrossed = None #A line marker to indicate that this item is hidden
+
         #Extensions are child items.
         #DynamicDynamic extensions need updating when the pitch/clef changes.
 
@@ -239,6 +241,7 @@ class GuiItem(QtGui.QGraphicsItemGroup):
         self.tuplets = [] #static
         self.chordGlyph = None #static
         self.channelGlyph = None #static
+        self.programGlyph = None #static
         self.triggerGlyph = None # static
         self.guiDirectivesPst = [] #static
         self.figuresGlyph = None #static
@@ -248,7 +251,48 @@ class GuiItem(QtGui.QGraphicsItemGroup):
         self.aboveStatics = []
         self.belowStatics = []
 
-        #self.extensions() #on load create all the stuff
+        if not type(self) is GuiChord:
+            self.extensions() #on load create all the stuff. This is partly redundant with chord.update()
+
+        self.updateVisibility()
+
+    def updateVisibility(self):
+        """The backend can be normal, hidden or transparent"""
+        if self.data.hidden:
+            if self.hiddenCrossed:
+                self.scene().removeItem(self.hiddenCrossed)
+                self.scene().removeItem(self.hiddenCrossed2)
+                self.hiddenCrossed = None
+                self.hiddenCrossed2 = None
+
+            line = QtGui.QGraphicsLineItem(QtCore.QLineF(0, TRACK_SIZE/2.1, 0, 0 ))
+            line2 = QtGui.QGraphicsLineItem(QtCore.QLineF(0, TRACK_SIZE/2.1, 0, 0 ))
+
+            line.setParentItem(self)
+            line2.setParentItem(self)
+
+            line.rotate(-20)
+            line.setPos(3, -3)
+            line.setPen(PEN_LINEFORBIDDEN)
+
+            line2.rotate(20)
+            line2.setPos(23, 5)
+            line2.setPen(PEN_LINEFORBIDDEN)
+
+            self.hiddenCrossed = line
+            self.hiddenCrossed2 = line2
+
+        else:
+            if self.hiddenCrossed:
+                self.scene().removeItem(self.hiddenCrossed)
+                self.scene().removeItem(self.hiddenCrossed2)
+                self.hiddenCrossed = None
+                self.hiddenCrossed2 = None
+
+        if self.data.transparent:
+            self.setOpacity(0.5)
+        else:
+            self.setOpacity(1)
 
     def verticalLine(self):
         line_vertical = QtGui.QGraphicsLineItem(QtCore.QLineF(0, 30, 0, 0))
@@ -260,7 +304,6 @@ class GuiItem(QtGui.QGraphicsItemGroup):
 
     def lineUpAboveStatics(self):
         offset = -TRACK_SIZE/4
-        #TODO: this gets executed two times. Why?!
 
         #the noteheads are sorted because the backend notesheads are sorted
         #and the GUI creates them one after another with a for x in list loop.
@@ -271,7 +314,7 @@ class GuiItem(QtGui.QGraphicsItemGroup):
             startY = 0
         for x in self.aboveStatics:
             if x: #not None
-                x.setPos(0, startY + offset)
+                x.setPos(5, startY + offset)
                 #print (x.shape().controlPointRect().height())
                 offset -= 8
 
@@ -318,13 +361,20 @@ class GuiItem(QtGui.QGraphicsItemGroup):
         (compare how far away both notes are from the middle line.
         Second for ledger lines"""
         notelist = self.data.notelist #it is always ordered.
+
         maxi = notelist[-1].pitch
         mini = notelist[0].pitch
+
         if maxi == 20:
             return (0, 0)
         else:
             return (self.yFormulaPart2(self.yFormulaPart1(mini, clefPitch)) , self.yFormulaPart2(self.yFormulaPart1(maxi, clefPitch)))
 
+    def hasMiddleLine(self, clefPitch):
+        """Return true if this chord has a middle line position.
+        c' in treble clef."""
+        return 25 in [self.yFormulaPart2(self.yFormulaPart1(note.pitch, clefPitch)) for note in self.data.notelist]
+
     def updateDynamic(self):
         """Redraw only parts that move on the Y axis.
         Only chords and the keysig need this currently because they
@@ -388,14 +438,14 @@ class GuiItem(QtGui.QGraphicsItemGroup):
                 self.aboveStatics.append(self.tuplets)
 
             t = self.data.tuplets
-            if t == [(2,3)]:
+            if t == [[2,3]]:
                 marker = "3"
                 #marker = "⅔" #triplet
-            elif t == [(4,6)]:
+            elif t == [[4,6]]:
                 marker = "6"
-            elif t == [(4,5)]:
+            elif t == [[4,5]]:
                 marker = "⅘"
-            elif t == [(2,5)]:
+            elif t == [[2,5]]:
                 marker = "⅖"
             else: #build our own fraction
                 marker = re.sub(r'\[|\]|\(|\)', "", str(self.data.tuplets).replace("),", ""))
@@ -507,10 +557,11 @@ class GuiItem(QtGui.QGraphicsItemGroup):
                 elif pstDirective[0][0:4] == "usr_":
                     pstGlyph = GuiText(pstDirective[1][0:4], ) #Use the directive
                     pstGlyph.rotate(-90)
+                    pstGlyph.translate(-20, 0) #this is actually the Y-direction. It moves the glyph downwards.
                 else:
                     pstGlyph = GuiText(pstDirective[0][0:4], ) #Use the key
                     pstGlyph.rotate(-90)
-                    pstGlyph.translate(-15, 0) #this is actually the Y-direction. It moves the glyph downwards.
+                    pstGlyph.translate(-20, 0) #this is actually the Y-direction. It moves the glyph downwards.
 
             pstGlyph.setParentItem(self)
             self.aboveStatics.append(pstGlyph)
@@ -526,12 +577,15 @@ class GuiItem(QtGui.QGraphicsItemGroup):
     def smfChannel(self):
         pass
 
+    def smfProgram(self):
+        pass
+
     def allFingers(self):
         raise RuntimeError("called allfinger for non chord. Error in API call")
 
 class GuiClef(GuiItem):
-    def __init__(self, backendItem, glyph, pitch, offset, forceSigs = None):  #offset is in note-position. 1 means one step in the notelines/between up. -1 down.
-        super(GuiClef, self).__init__(backendItem, displacement = DISPLACE, forceSigs = forceSigs)
+    def __init__(self, backendItem, glyph, pitch, offset, forceSigs = None, parentTrack = None):  #offset is in note-position. 1 means one step in the notelines/between up. -1 down.
+        super(GuiClef, self).__init__(backendItem, displacement = DISPLACE, forceSigs = forceSigs, parentTrack = parentTrack)
         self.pitch = pitch
         self.breakClefLoop = True #instead of typesetting this is a break marker when track.clefUpdate() runs.
         self.mainGlyph = GuiGlyph(text = glyph, fontScale = 1.6)
@@ -541,15 +595,15 @@ class GuiClef(GuiItem):
 
 class GuiChord(GuiItem):
     """One GuiChord holds several GuiNotes. It makes it possible to combine notehead(s) with a stem(s), directives etc."""
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiChord, self).__init__(backendItem, forceSigs = forceSigs)
-        #The invis glyph is to make selection work.
-        self.invis = GuiGlyph(text = " ")
-        self.addToGroup(self.invis)
-        self.noteheads = [] #dynamic (see GuiItem)
-        self.ledgerlines = [] #dynamic
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiChord, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.stem = None
         self.flags = []
+        #The invis glyph is to make selection work.
+        self.invis = GuiGlyph(text = " ")
+        self.noteheads = [] #dynamic (see GuiItem)
+        self.ledgerlines = [] #dynamic
+        self.addToGroup(self.invis)
         self.update()
 
     def allFingers(self):
@@ -561,7 +615,7 @@ class GuiChord(GuiItem):
     def extensions(self):
         super(GuiChord, self).extensions()
         self.smfChannel()
-
+        self.smfProgram()
 
     def updateLedgerLines(self):
         #Draw Ledger Lines
@@ -569,17 +623,17 @@ class GuiChord(GuiItem):
             self.scene().removeItem(line)
         self.ledgerlines = []
 
-        start_under = 50
-        start_above = -10
+        start_under, start_above, lower_boundary, upper_boundary, offset_below, offset_above, middle_line_special = self.track.ledgerLinesDataSetCurrent
+
         nrOfLedgerLinesUnder = 0
         nrOfLedgerLinesAbove = 0
         #Determine if we need ledger lines.
-        if self.cachedMinMax[0] >=  23:
-            nrOfLedgerLinesUnder = math.floor(self.cachedMinMax[0] / PITCH_MOD - 1.4)
+        if self.cachedMinMax[0] >= lower_boundary:
+            nrOfLedgerLinesUnder = math.floor(self.cachedMinMax[0] / PITCH_MOD - 1.4 + offset_below)
             if not nrOfLedgerLinesUnder:
                 nrOfLedgerLinesUnder = 1
-        if self.cachedMinMax[1] <= -33:
-            nrOfLedgerLinesAbove = math.floor(-1 * self.cachedMinMax[1] / PITCH_MOD - 2.4)
+        if self.cachedMinMax[1] <= upper_boundary:
+            nrOfLedgerLinesAbove = math.floor(-1 * self.cachedMinMax[1] / PITCH_MOD - 2.4 + offset_above)
             if not nrOfLedgerLinesAbove:
                 nrOfLedgerLinesAbove = 1
         #Now drawing the lines. We always draw both, for chords which spread wide.
@@ -596,6 +650,13 @@ class GuiChord(GuiItem):
             lines_above.setPos(2,0)
             self.ledgerlines.append(lines_above)
 
+        if middle_line_special and self.hasMiddleLine(self.cachedClefPitch): #In case of dual view the middle line gets no ledger line. We create one.
+            lines_middle = QtGui.QGraphicsLineItem(QtCore.QLineF(0, 50, 22, 50))
+            lines_middle.setPen(PEN_LINE)
+            lines_middle.setParentItem(self)
+            lines_middle.setPos(2,0)
+            self.ledgerlines.append(lines_middle)
+
     def updateDynamic(self):
         """Create the noteheads and accidentals.
         Each update all heads get deleted and recreated.
@@ -653,6 +714,21 @@ class GuiChord(GuiItem):
                 head.dots.setParentItem(head)
                 head.dots.setPos(FONT_SIZE, 0)
 
+    def getStemDirection(self, lowest, highest):
+        """Returns True for right/up and False for left/down
+        Higher is the negative direction. These are Qt coordinates.
+        All values include the given boundaries:
+
+        higher than -5: Stem left/down
+        -4 to 55: Stem right/up.
+
+        If dual view:
+        56 to 114: left/down
+        116 to inf: right/up
+        """
+        val = lowest + highest
+        return -4 <= val <=55  or (val >= -5 and not self.track.dualView) or (self.track.dualView and val >= 116)
+
     def updateStandaloneStemAndFlag(self):
         """Does all the calculation if and what stem to draw."""
         if self.stem:
@@ -666,7 +742,7 @@ class GuiChord(GuiItem):
 
         #Draw stem
         if not 1536 <= self.cachedBaseDuration < 6144:  #not smaller than a whole note and not higher than a longa -> not for whole and breve.
-            rightStemUp = self.cachedMinMax[0] + self.cachedMinMax[1] >= -5
+            rightStemUp = self.getStemDirection(self.cachedMinMax[0], self.cachedMinMax[1])
 
             if rightStemUp: #right stem, up
                 stem = QtGui.QGraphicsLineItem(QtCore.QLineF(0, self.cachedMinMax[0] + TRACK_SIZE/4, 0, self.cachedMinMax[1] - PITCH_MOD))
@@ -709,7 +785,8 @@ class GuiChord(GuiItem):
         else:
             beamDirection = (self.cachedDuration + self.displacement) * config.DURATION_MOD
 
-        rightStemUp = self.cachedGroupStemExtremePitches[0] + self.cachedGroupStemExtremePitches[1] >= -5
+        #rightStemUp = self.cachedGroupStemExtremePitches[0] + self.cachedGroupStemExtremePitches[1] >= -5
+        rightStemUp = self.getStemDirection(self.cachedGroupStemExtremePitches[0], self.cachedGroupStemExtremePitches[1])
         if rightStemUp: #right stem, up, defined by group
             stem = QtGui.QGraphicsLineItem(QtCore.QLineF(0,
                                                         self.cachedMinMax[0] + TRACK_SIZE/4, #lowest point. The individual notehead.
@@ -761,12 +838,14 @@ class GuiChord(GuiItem):
         #start gui drawing
         if channelString or channelString == "": #TODO: Workaround. Somehow delete below did not work.
             if not self.channelGlyph: #the first time.
-                self.channelGlyph = GuiText(channelString)
+                suffix = "c" if channelString else ""
+                self.channelGlyph = GuiText(channelString+suffix)
                 self.channelGlyph.setParentItem(self)
                 self.belowStatics.append(self.channelGlyph)
                 self.channelGlyph.setDefaultTextColor(QtGui.QColor("green"))
             else:
-                self.channelGlyph.setPlainText(channelString)
+                suffix = "c" if channelString else ""
+                self.channelGlyph.setPlainText(channelString+suffix)
             self.lineUpBelowStatics()
 
         elif self.channelGlyph: #There was one before. We had a delete
@@ -774,9 +853,37 @@ class GuiChord(GuiItem):
             self.scene().removeItem(self.channelGlyph)
             self.channelGlyph = None
 
+    def smfProgram(self):
+        #Build string from data
+        programString = ""
+        if self.data.programOffset > 0:
+            programString = "+" + str(self.data.programOffset)
+        elif self.data.programOffset < 0:
+            programString = str(self.data.programOffset)
+        if self.data.forceProgram >= 0:
+            programString = str(1 + self.data.forceProgram) + programString  #+1 to convert smf 0-15 to human 1-16
+
+        #start gui drawing
+        if programString or programString == "": #TODO: Workaround. Somehow delete below did not work.
+            if not self.programGlyph: #the first time.
+                suffix = "p" if programString else ""
+                self.programGlyph = GuiText(programString+suffix)
+                self.programGlyph.setParentItem(self)
+                self.belowStatics.append(self.programGlyph)
+                self.programGlyph.setDefaultTextColor(QtGui.QColor("cyan"))
+            else:
+                suffix = "p" if programString else ""
+                self.programGlyph.setPlainText(programString+suffix)
+            self.lineUpBelowStatics()
+
+        elif self.programGlyph: #There was one before. We had a delete
+            self.belowStatics.remove(self.programGlyph)
+            self.scene().removeItem(self.programGlyph)
+            self.programGlyph = None
+
 class GuiRest(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiRest, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiRest, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.mainGlyph = GuiGlyph(text = "", fontScale = 1.6)
         if self.data.pitch == "s": #skips
             self.mainGlyph.setOpacity(0.5)
@@ -805,8 +912,8 @@ class GuiClosedContainer(GuiItem):
     """A container with no visible content. The cursor treats this
     as one big item"""
 
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiClosedContainer, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiClosedContainer, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.widthDependentOnDisplacement = True
 
         self.startGlyph = GuiText(text = '\U0001D115')
@@ -870,8 +977,8 @@ class GuiMultiMeasureRest(GuiItem):
     backend cursor system. Linked Items and containers do not work that
     way since the gui does not use the backend cursor. """
 
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiMultiMeasureRest, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiMultiMeasureRest, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.dataOrg = self.data
         self.data = self
         self.mainGlyph = GuiGlyph(text = "\U0001D129", fontScale = 1.6)
@@ -884,6 +991,14 @@ class GuiMultiMeasureRest(GuiItem):
         self.measures.setPos(FONT_SIZE, TEXT_SCALE_CORRECTION)
         self.setPos(0,0)
 
+    @property
+    def figures(self):
+        return self.dataOrg.figures
+
+    @property
+    def chordsymbols(self):
+        return self.dataOrg.chordsymbols
+
     @property
     def cachedDuration(self):
         return self.dataOrg.measures * self.cachedTimesigData.nominator * self.cachedTimesigData.denominator
@@ -914,8 +1029,8 @@ class GuiMultiMeasureRest(GuiItem):
 
 class GuiPlaceholder(GuiMultiMeasureRest):
     """MMRest but with more space in Lilypond"""
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiPlaceholder, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiPlaceholder, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.mainGlyph.setDefaultTextColor(QtGui.QColor("green"))
 
 class GuiUpbeat(GuiItem):
@@ -924,8 +1039,8 @@ class GuiUpbeat(GuiItem):
     This has no effect on playback or lilypond.
     See Multi Measure Rest"""
 
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiUpbeat, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiUpbeat, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.dataOrg = self.data
         self.data = self
         try: #who knows what weird combination they want. better prepare for the unknown
@@ -978,8 +1093,8 @@ class GuiKeySignature(GuiItem):
     To decide on which pitch/line to draw the glyph we search for the
     first position from high to low which has no ledger line for the
     current clef."""
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiKeySignature, self).__init__(backendItem, displacement = DISPLACE, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiKeySignature, self).__init__(backendItem, displacement = DISPLACE, forceSigs = forceSigs, parentTrack = parentTrack)
         self.breakKeysigLoop = True #marks this item as keysig for track.keysigUpdate
         self.update()
         #TODO: less update, more static.
@@ -1021,8 +1136,8 @@ class GuiKeySignature(GuiItem):
             self.addToGroup(self.mainGlyph)
 
 class GuiTimeSignature(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiTimeSignature, self).__init__(backendItem, displacement = DISPLACE/2 , forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiTimeSignature, self).__init__(backendItem, displacement = DISPLACE/2 , forceSigs = forceSigs, parentTrack = parentTrack)
         #self.nominator = self.data.nominator   #example: x/4 Upper number
         #self.denominator = self.data.denominator #example: 384/x lower number
         self.breakTimesigLoop = True #instead of typesetting this is a break marker when track.timesigUpdate() runs. Additionaly this is used by timesig index generation in firstPass
@@ -1036,20 +1151,24 @@ class GuiTimeSignature(GuiItem):
 
 class GuiDynamicSignature(GuiItem):
     """Take the expression string and place it into the scene"""
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiDynamicSignature, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiDynamicSignature, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.displacement = DISPLACE/2
         self.mainGlyph = GuiText(text = "", fontScale = 1.5)
-        self.mainGlyph.setHtml("<b><i>" + self.data._expression + "</i></b>")
         self.mainGlyph.setPos(5, TRACK_SIZE/2.5)
         self.verticalLine()
         self.addToGroup(self.mainGlyph)
         self.setPos(0,0)
+        self.updateStatic()
+
+    def updateStatic(self):
+        self.mainGlyph.setHtml("<b><i>" + str(self.data._expression) + "</i></b>")
+
 
 class GuiPerformanceSignature(GuiItem):
     """Take the expression string and place it into the scene"""
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiPerformanceSignature, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiPerformanceSignature, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.displacement = DISPLACE/2
         self.mainGlyph = GuiText(text = "\u2707", fontScale = 2)
         self.addToGroup(self.mainGlyph)
@@ -1066,8 +1185,8 @@ class GuiWaitForChord(GuiItem):
     """The difference to GuiDynamicSignature is that this uses the
     lilystring variable and strips any backslashes.
     Different font as well."""
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiWaitForChord, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiWaitForChord, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.displacement = DISPLACE
         self.mainGlyph = GuiText(text = self.data.lilystring.lstrip('\\'))
         self.mainGlyph.setPos(0, TRACK_SIZE/2.5)
@@ -1075,8 +1194,8 @@ class GuiWaitForChord(GuiItem):
         self.setPos(0,0)
 
 class GuiContainerStart(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiContainerStart, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiContainerStart, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.setFlag(QtGui.QGraphicsItem.ItemIsSelectable, False)
         self.breakContainerLoop = True #instead of typechecking this is a break marker when adding items in containers.
         self.displacement = DISPLACE/2
@@ -1101,8 +1220,8 @@ class GuiContainerStart(GuiItem):
             self.nameGlyph.setPlainText(self.data.parentContainer.uniqueContainerName)
 
 class GuiContainerEnd(GuiItem):
-    def __init__(self, backendItem, forceSigs = None): #, dataContainer):   #dataContainer is not needed currently. And if it becomes needed don't forget to forward it in insertRelativeToContainerBegin
-        super(GuiContainerEnd, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None): #, dataContainer):   #dataContainer is not needed currently. And if it becomes needed don't forget to forward it in insertRelativeToContainerBegin
+        super(GuiContainerEnd, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         #self.dataContainer = dataContainer #is set directly on GUI insert.
         self.setFlag(QtGui.QGraphicsItem.ItemIsSelectable, False)
         self.breakContainerLoop = None #! important. All other items have False. This is needed in insertRelativeToContainerBegin to prevent typechecking
@@ -1153,8 +1272,8 @@ class GuiMarkup(GuiItem):
     """The difference to GuiDynamicSignature is that this uses the
     lilystring variable and strips any backslashes.
     Different font as well."""
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiMarkup, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiMarkup, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.displacement = DISPLACE/2
         self.mainGlyph = GuiText(text = self.data.lilystring[:11])
         self.mainGlyph.rotate(-90)
@@ -1168,8 +1287,8 @@ class GuiMarkup(GuiItem):
 
 
 class GuiSegno(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiSegno, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiSegno, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.displacement = DISPLACE/4
         self.mainGlyph = GuiText(text = '\U0001D10B')
         self.mainGlyph.setScale(4)
@@ -1179,8 +1298,8 @@ class GuiSegno(GuiItem):
         self.setPos(0,0)
 
 class GuiCoda(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiCoda, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiCoda, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.displacement = DISPLACE/4
         self.mainGlyph = GuiText(text = '\U0001D10C')
         self.mainGlyph.setScale(4)
@@ -1190,8 +1309,8 @@ class GuiCoda(GuiItem):
         self.setPos(0,0)
 
 class GuiFine(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiFine, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiFine, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.displacement = DISPLACE/2
         self.mainGlyph = GuiText(text = 'Fine')
         self.mainGlyph.setScale(2)
@@ -1202,8 +1321,8 @@ class GuiFine(GuiItem):
         self.setPos(0,0)
 
 class GuiGotoSegno(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiGotoSegno, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiGotoSegno, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.displacement = DISPLACE/4
         self.mainGlyph = GuiText(text = '\U0001D109')
         self.mainGlyph.setScale(4)
@@ -1213,8 +1332,8 @@ class GuiGotoSegno(GuiItem):
         self.setPos(0,0)
 
 class GuiGotoCapo(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiGotoCapo, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiGotoCapo, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.displacement = DISPLACE/4
         self.mainGlyph = GuiText(text = '\U0001D10A')
         self.mainGlyph.setScale(4)
@@ -1224,8 +1343,8 @@ class GuiGotoCapo(GuiItem):
         self.setPos(0,0)
 
 class GuiGotoCoda(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiGotoCoda, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiGotoCoda, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.displacement = DISPLACE/4
         self.mainGlyph = GuiText(text = '\u21B7\U0001D10C')
         self.mainGlyph.setScale(4)
@@ -1234,8 +1353,8 @@ class GuiGotoCoda(GuiItem):
         self.setPos(0,0)
 
 class GuiPedalSustainChange(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiPedalSustainChange, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiPedalSustainChange, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.displacement = DISPLACE/10
         self.mainGlyph = GuiText(text = '𝆰')
         self.mainGlyph.setScale(3)
@@ -1245,8 +1364,8 @@ class GuiPedalSustainChange(GuiItem):
         self.setPos(0,0)
 
 class GuiSpecialBarline(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiSpecialBarline, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiSpecialBarline, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.repeatGlyph = None
         self.mainGlyph = GuiText(text = dictionaries.barlines[self.data.lilypond.split('"')[1]])
         self.mainGlyph.setScale(4)
@@ -1267,8 +1386,8 @@ class GuiSpecialBarline(GuiItem):
             self.repeatGlyph.setPos(-5, 45)
 
 class GuiAlternateEnd(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiAlternateEnd, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiAlternateEnd, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.endingNumbers = None
         self.mainGlyph = GuiText(text = self.data.text)
         #self.mainGlyph.setScale(1)
@@ -1294,8 +1413,8 @@ class GuiAlternateEnd(GuiItem):
         self.mainGlyph.setPlainText(self.data.text)
 
 class GuiAlternateEndClose(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiAlternateEndClose, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiAlternateEndClose, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.displacement = DISPLACE/2
         self.mainGlyph = QtGui.QGraphicsLineItem(QtCore.QLineF(0, 55, 0, 0))
         self.mainGlyph.setPen(PEN_BEAM)
@@ -1311,8 +1430,8 @@ class GuiAlternateEndClose(GuiItem):
         self.setPos(0,0)
 
 class GuiTempoSignature(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiTempoSignature, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiTempoSignature, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.endingNumbers = None
         self.mainGlyph = GuiText(text = "") #"" for now
         self.mainGlyph.setPos(0, -40)
@@ -1326,8 +1445,8 @@ class GuiTempoSignature(GuiItem):
         self.mainGlyph.setPlainText("⌛" + self.data.tempostring + " " + api.lilypond.dur2ly[self.data.referenceTicks] + "=" + str(self.data.beatsPerMinute))
 
 class GuiTempoModification(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiTempoModification, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiTempoModification, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.endingNumbers = None
         self.mainGlyph = GuiText(text = "") #"" for now
         self.mainGlyph.setPos(0, -40)
@@ -1342,12 +1461,12 @@ class GuiTempoModification(GuiItem):
     updateDynamic = updateStatic # the api signal for augment is dynamic.
 
 class GuiChannelChange(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiChannelChange, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiChannelChange, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.mainGlyph = GuiText(text = "") #"" for now
-        self.mainGlyph.setScale(2)
+        self.mainGlyph.setScale(1.5)
         self.displacement = DISPLACE/2
-        self.mainGlyph.setPos(0, -20)
+        self.mainGlyph.setPos(-5, -30)
         self.verticalLine()
         self.addToGroup(self.mainGlyph)
         self.setPos(0,0)
@@ -1359,14 +1478,37 @@ class GuiChannelChange(GuiItem):
             self.mainGlyph.setPlainText("C" + str(self.data.number +1))
         else: #relative
             if self.data.number > 0:
-                extra = "+"
+                extra = "C+"
             else:
-                extra = ""
+                extra = "C" #the minus is added by the number
+            self.mainGlyph.setPlainText(extra + str(self.data.number))
+
+class GuiProgramChange(GuiItem):
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiProgramChange, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
+        self.mainGlyph = GuiText(text = "") #"" for now
+        self.mainGlyph.setScale(1.5)
+        self.displacement = DISPLACE/2
+        self.mainGlyph.setPos(-5, -30)
+        self.verticalLine()
+        self.addToGroup(self.mainGlyph)
+        self.setPos(0,0)
+        self.updateStatic()
+        self.mainGlyph.setDefaultTextColor(QtGui.QColor("cyan"))
+
+    def updateStatic(self):
+        if type(self.data) is api.items.ProgramChangeAbsolute:
+            self.mainGlyph.setPlainText("P" + str(self.data.number +1))
+        else: #relative
+            if self.data.number > 0:
+                extra = "P+"
+            else:
+                extra = "P" #the minus is added by the number
             self.mainGlyph.setPlainText(extra + str(self.data.number))
 
 class GuiInstrumentChange(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiInstrumentChange, self).__init__(backendItem, forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiInstrumentChange, self).__init__(backendItem, forceSigs = forceSigs, parentTrack = parentTrack)
         self.displacement = DISPLACE/2
         self.mainGlyph = GuiText(text = "♺", fontScale = 2)
         self.mainGlyph.setPos(5, 0)
@@ -1385,19 +1527,19 @@ class GuiInstrumentChange(GuiItem):
 
 
 class GuiSlurOn(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiSlurOn, self).__init__(backendItem, displacement = DISPLACE/4, mainGlyph = "(", forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiSlurOn, self).__init__(backendItem, displacement = DISPLACE/4, mainGlyph = "(", forceSigs = forceSigs, parentTrack = parentTrack)
 
 class GuiSlurOff(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiSlurOff, self).__init__(backendItem, displacement = DISPLACE/4, mainGlyph = ")", forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiSlurOff, self).__init__(backendItem, displacement = DISPLACE/4, mainGlyph = ")", forceSigs = forceSigs, parentTrack = parentTrack)
         self.setPos(4,0)
 
 class GuiPhrasingSlurOn(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiPhrasingSlurOn, self).__init__(backendItem, displacement = DISPLACE/2, mainGlyph = "((", forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiPhrasingSlurOn, self).__init__(backendItem, displacement = DISPLACE/2, mainGlyph = "((", forceSigs = forceSigs, parentTrack = parentTrack)
 
 
 class GuiPhrasingSlurOff(GuiItem):
-    def __init__(self, backendItem, forceSigs = None):
-        super(GuiPhrasingSlurOff, self).__init__(backendItem, displacement = DISPLACE/2, mainGlyph = "))", forceSigs = forceSigs)
+    def __init__(self, backendItem, forceSigs = None, parentTrack = None):
+        super(GuiPhrasingSlurOff, self).__init__(backendItem, displacement = DISPLACE/2, mainGlyph = "))", forceSigs = forceSigs, parentTrack = parentTrack)
