@@ -39,6 +39,10 @@ class ListenerGlobal(Listener):
 
     def jackMidiInToggleMute(self, onOrOff):
         main.ui.actionMIDI_Note_Entry.setChecked(onOrOff)
+        if onOrOff:
+            main.prevailingMode()
+        else:
+            main.defaultModalCommands()
 
     def workspaceChanged(self, newActiveWorkspace):
         """Send the active workspace or None if no file is open.
@@ -54,6 +58,11 @@ class ListenerGlobal(Listener):
     def new(self, backendWorkspace):
         main.new(backendWorkspace)
 
+    def cleanAgain(self):
+        """The undo system reached a point where it got clean again"""
+        main.session.setSavestatusClean()
+
+
 class ListenerCollections(Listener):
     def __init__(self):
         super(ListenerCollections, self).__init__()
@@ -61,7 +70,6 @@ class ListenerCollections(Listener):
     def load(self, loadedCollection):
         pass
 
-
 class ListenerRecord(Listener):
     """Midi in"""
     def __init__(self):
@@ -170,6 +178,8 @@ class ListenerItem(Listener):
             api.items.TempoModification: items.GuiTempoModification,
             api.items.ChannelChangeRelative: items.GuiChannelChange,
             api.items.ChannelChangeAbsolute: items.GuiChannelChange,
+            api.items.ProgramChangeRelative: items.GuiProgramChange,
+            api.items.ProgramChangeAbsolute: items.GuiProgramChange,
             api.items.InstrumentChange: items.GuiInstrumentChange,
             api.items.SlurOn: items.GuiSlurOn,
             api.items.SlurOff: items.GuiSlurOff,
@@ -179,7 +189,7 @@ class ListenerItem(Listener):
             }
 
         if itemType in d:
-            return d[itemType](item, forceSigs = forceSigs)
+            return d[itemType](item, forceSigs = forceSigs, parentTrack = main.session.currentGuiWorkspace.currentTrack)
 
         elif itemType is api.items.Clef:
             creationData = dictionaries.clefs[item.clefString + item.octave]  #0: Clef-Glyph, 1:Pitch Offset #2:Graphic Offset
@@ -210,11 +220,13 @@ class ListenerItem(Listener):
                 return new
             else:
                 new = items.GuiItem(item, displacement = DISPLACE/2, mainGlyphShift = mainGlyphShift, mainGlyph = mainglyph, fontScale = fontScale , forceSigs = forceSigs)
-                line_vertical = QtGui.QGraphicsLineItem(QtCore.QLineF(0, 30, 0, 0))
-                line_vertical.setPen(PEN_POSITION)
-                line_vertical.setParentItem(new)
-                line_vertical.setPos(12, 5)
-                new.addToGroup(line_vertical)
+                new.verticalLine()
+                #No vertical line for barlines.
+                #line_vertical = QtGui.QGraphicsLineItem(QtCore.QLineF(0, 30, 0, 0))
+                #line_vertical.setPen(PEN_POSITION)
+                #line_vertical.setParentItem(new)
+                #line_vertical.setPos(12, 5)
+                #new.addToGroup(line_vertical)
                 return new
 
     def insertAtCursor(self, item, getContainer, standaloneInsert = True):
@@ -327,6 +339,10 @@ class ListenerItem(Listener):
         self._allItems(backendItem, "updateDynamic")
         self.updateViewport()
 
+    def updateVisibility(self, backendItem):
+        """Update if the item is normal, transparent or hidden"""
+        self._allItems(backendItem, "updateVisibility")
+
     def extensions(self, backenItem):
         #the real extensions signal is in listener chord.
         api.l_chord.extensions(backenItem)
@@ -342,6 +358,9 @@ class ListenerItem(Listener):
     def smfChannel(self, backendItem):
         self._allItems(backendItem, "smfChannel") #Below the Item
 
+    def smfProgram(self, backendItem):
+        self._allItems(backendItem, "smfProgram") #Below the Item
+
     def smfTrigger(self, backendItem):
         self._allItems(backendItem, "smfTrigger")
 
@@ -468,16 +487,26 @@ class ListenerScore(Listener):
         """Trigger a full gui redraw, as if the file was loaded anew.
         It doesn't get much more unperformant than this.
         If your GUI is very very fast this is all you ever need, simply
-        call it after every change."""
+        call it after every change and ignore all other drawing and
+        update signals."""
         main.session.currentGuiWorkspace.fullReload()
 
     def playbackStart(self):
         """The playback has started"""
-        main.session.currentGuiWorkspace.playbackCursorSetVisible(True)
+        #main.session.currentGuiWorkspace.playbackCursorSetVisible(True)
+        for guiScore in main.session.scenes.values():
+            guiScore.playbackCursor.playbackActive = False
+            guiScore.playbackCursor.hide()
+        main.session.currentGuiWorkspace.playbackCursor.playbackActive = True
+
 
     def playbackStop(self):
         """The playback has stopped"""
-        main.session.currentGuiWorkspace.playbackCursorSetVisible(False)
+        #TODO: remove try/except when there is "stop playback on tab"
+        try: #it is possible that no tab is open and playback is still running.
+            main.session.currentGuiWorkspace.playbackCursorSetVisible(False)
+        except:
+            pass
 
     def playbackSetPosition(self, absoluteUnfoldedTicks):
         """Update the playhead/playback cursor position.
@@ -485,7 +514,12 @@ class ListenerScore(Listener):
         This receives the absolute, unfolded and global ticks.
 
         It is up to the gui to handle repeats, jumps and containers."""
-        main.session.currentGuiWorkspace.playbackCursorSetTicks(absoluteUnfoldedTicks)
+        #TODO: remove try/except when there is "stop playback on tab"
+        try: #it is possible that no tab is open and playback is still running.
+            main.session.currentGuiWorkspace.playbackCursorSetVisible(True)
+            main.session.currentGuiWorkspace.playbackCursorSetTicks(absoluteUnfoldedTicks)
+        except:
+            pass
 
     def playbackPanic(self):
         """A special midi panic signal. Also calls stop. If in doubt
@@ -497,9 +531,9 @@ class ListenerFormGenerator(Listener):
     def __init__(self):
         super(ListenerFormGenerator, self).__init__()
 
-    def generateForm(self, dictionary, title, comment = ""):
+    def generateForm(self, dictionary, title, comment = "", autocomplete = []):
         #TODO: Doc widgets
-        return fedit(dictionary, title, comment)
+        return fedit(dictionary, title, comment, autocomplete=autocomplete)
 
 class ListenerNote(Listener):
     def __init__(self):
@@ -545,8 +579,6 @@ class ListenerChord(Listener):
         self._allItems(backendItem, "substitutionMarker") #Below the Chord
 
 
-
-
 def init():
     """Call after main has been set"""
     api.STANDALONE = False #Switch backend into slave mode.
